#coding:utf-8
import json
import random
from urllib.parse import urlparse  #正则url标准库
import re
from urllib import parse
from wadeTools import wadeTools_Request, wadeTools_UserJSON, wadeTools_ReadAndWrite, wadeTools_Text,wadeTools_error
import requests
import time

#LOCAL 提交模板
SHOP_CARD_CODE ="""{"id":"【gid】","iframeSrc":"//baijiahao.baidu.com/builder/author/static/goods?id=【gid】","goodsType":"jingdong","original_title":"【title】","new_title":"【new_title】","image_list":[{"src":"【image_list】"}],"num_id":【num_id】,"price":"【price】","amout":"【num_id】","slink":"【slink】","original_price":0,"platform":"【platformName】","gid":"【gid】","commission":"【commission】","type":"news","saleCount":"【saleNum】","TPName":"","goods_prompt":""}"""
SHOP_CARD_WEB_CODE = """<p><br></p><p contenteditable="false" class="goods-iframe-wrapper"><iframe data-bjh-box="goods" data-goods-type="jingdong" data-goods-id="【gid】" data-goods-num_id="【num_id】" scrolling="no" frameborder="0" src="//baijiahao.baidu.com/builder/author/static/goods?id=【gid】" data-bjh-params="【商品卡源码】" class="edui-faked-goods" data-diagnose-id="174dd570c36379a49153045dfe2fa74d"></iframe></p><p><br></p>"""
SHOP_IMG_URL = """[{"src":"【图片链接】"}]"""
ARTICLE_IMG = """[{"src":"【图片一】@c_1,w_843,h_562,x_0,y_135","cropData":{"x":0,"y":135,"width":843,"height":562},"machine_chooseimg":1,"isLegal":0},{"src":"【图片二】@c_1,w_414,h_276,x_0,y_310","cropData":{"x":0,"y":310,"width":414,"height":276},"machine_chooseimg":1,"isLegal":0},{"src":"【图片三】@c_1,w_540,h_360,x_0,y_124","cropData":{"x":0,"y":124,"width":540,"height":360},"machine_chooseimg":1,"isLegal":0}]"""
ARTICLE_IMG_MAP = """[{"src":"【图片一】@c_1,w_843,h_562,x_0,y_135","origin_src":"【图片一】@wm_2,t_55m+5a625Y+3L+Wlvei0p+WTpQ==,fc_ffffff,ff_U2ltSGVp,sz_22,x_14,y_14"},{"src":"【图片二】@c_1,w_414,h_276,x_0,y_310","origin_src":"【图片二】@wm_2,t_55m+5a625Y+3L+Wlvei0p+WTpQ==,fc_ffffff,ff_U2ltSGVp,sz_11,x_7,y_7"},{"src":"【图片三】@c_1,w_540,h_360,x_0,y_124","origin_src":"【图片三】@wm_2,t_55m+5a625Y+3L+Wlvei0p+WTpQ==,fc_ffffff,ff_U2ltSGVp,sz_14,x_9,y_9"}]"""
IMAGE_LIST =[]
FENGMIAN_IMGR_URL =''
#获取全局变量：
# COOKIE=wadeTools_gol.get_value('COOKIE') #基础配置
# TOKEN=wadeTools_gol.get_value('TOKEN')  #基础百家toke
# PUBLIST_NUM=wadeTools_gol.get_value('PUBLIST_NUM')
# SHOP_CARD_CODE=wadeTools_gol.get_value('SHOP_CARD_CODE')
# SHOP_CARD_WEB_CODE=wadeTools_gol.get_value('SHOP_CARD_WEB_CODE')
# SHOP_IMG_URL=wadeTools_gol.get_value('SHOP_IMG_URL')
# ARTICLE_IMG=wadeTools_gol.get_value('ARTICLE_IMG')
# ARTICLE_IMG_MAP=wadeTools_gol.get_value('ARTICLE_IMG_MAP')
# IMAGE_LIST=wadeTools_gol.get_value('IMAGE_LIST') #本页面变量

#本地变量

# TITLE=wadeTools_gol.get_value('TITLE')
# CONTENT=wadeTools_gol.get_value('CONTENT')
# ABSTRACT=wadeTools_gol.get_value('ABSTRACT')
# ITEM_ID=wadeTools_gol.get_value('ITEM_ID',100028103960)



'''百度初始化'''
def baiduInit(COOKIE):


    url = 'https://baijiahao.baidu.com/builder/app/appinfo?'
    html = wadeTools_Request.wade_Request_get(url, addHeader={"Cookie": COOKIE})
    htmlDict = html.json()
    #print(htmlDict)
    #name = wadeTools_UserJSON.get_dict_by_key(htmlDict,'22222')
    errno = wadeTools_UserJSON.get_dict_by_key(htmlDict,'ext_info')
    location = wadeTools_UserJSON.get_dict_by_key(htmlDict,'location')
    app_level_desc = wadeTools_UserJSON.get_dict_by_key(htmlDict,'app_level_desc')
    app_id = wadeTools_UserJSON.get_dict_by_key(htmlDict,'app_id')
    # print(htmlDict)
    global PUBLIST_NUM
    PUBLIST_NUM = wadeTools_UserJSON.get_dict_by_key(htmlDict,'publish_num')
    uname = wadeTools_UserJSON.get_dict_by_key(htmlDict,'uname')
    domain = wadeTools_UserJSON.get_dict_by_key(htmlDict,'domain')
    return uname,PUBLIST_NUM
'''转换外链图片为百度图片'''
def baiduImageUrl(COOKIE,imageURL = 'https://pica.zhimg.com/50/v2-f78f790008da504b230ea3c28f8ef62e_720w.jpg?source=1940ef5c'):

    '''转换外链图片为百度图片'''
    # imageURL = 'https://pica.zhimg.com/50/v2-f78f790008da504b230ea3c28f8ef62e_720w.jpg?source=1940ef5c'
    url = f'https://baijiahao.baidu.com/builderinner/api/content/file/image/dump?usage=content&article_type=news&is_waterlog=1&url={imageURL}'  # 旧版转链
    url = f'https://baijiahao.baidu.com/pcui/picture/dumpproxy?usage=content&article_type=news&is_waterlog=1&url={imageURL}'
    html = wadeTools_Request.wade_Request_get(url, addHeader={"Cookie": COOKIE})
    htmlDict = html.json()
    print(htmlDict)

    try:
        # 参数保存
        bos_url = htmlDict['data']['bos_url']  # 水印链接
        # no_waterlog_bos_url = htmlDict['data']['no_waterlog_bos_url']  # 无水印链接
        # mime = htmlDict['data']['mime']  # 类型
        # height = htmlDict['data']['height']  # 高
        # width = htmlDict['data']['width']  # 宽
        # error_code = htmlDict['error_code']  # 错误码 0
        # error_msg = htmlDict['error_msg']  # 状态：success
        # errno = htmlDict['errno']  # 0
        print("url换链成功")
        return bos_url
    except Exception as e:
        print(e)
        print("imageURL转百度链接转换失败了")
        return ''

'''获取商品sign标识'''
def baidu_getShop_sign(COOKIE):
    url = 'https://cecom.baidu.com/m/shop/sdk/choosegoods/'
    html = wadeTools_Request.wade_Request_get(url,addHeader={"Cookie": COOKIE})

    #获取html中的js文件地址
    js_urlList = wadeTools_Request.get_Request_JsFiles(html.text)
    if len(js_urlList)>0:
        for jsURL in js_urlList:
            # print(jsURL)
            jshtml = wadeTools_Request.wade_Request_get(jsURL, addHeader={"Cookie": COOKIE})
            # print(jshtml.text)
            if '/proxy/select/search_goods?access_name=cecom_fe&ak=cecom_fe&sign=' in jshtml.text:
                js_sign = wadeTools_Text.wade_match_MiddleText(A='/proxy/select/search_goods\?access_name=cecom_fe&ak=cecom_fe&sign=',B ='"',content =jshtml.text)
                wadeTools_ReadAndWrite.wadeDownloadFile(filePath='1',fileName=f'123.js',html=jshtml)  #下载没用了
                return js_sign[0]

def baidu_selectShopItem(COOKIE,ITEM_ID):
    SHOP_CARD_CODE = """{"id":"【gid】","iframeSrc":"//baijiahao.baidu.com/builder/author/static/goods?id=【gid】","goodsType":"jingdong","original_title":"【title】","new_title":"【new_title】","image_list":[{"src":"【image_list】"}],"num_id":【num_id】,"price":"【price】","amout":"【num_id】","slink":"【slink】","original_price":0,"platform":"【platformName】","gid":"【gid】","commission":"【commission】","type":"news","saleCount":"【saleNum】","TPName":"","goods_prompt":""}"""
    SHOP_CARD_WEB_CODE = """<p><br></p><p contenteditable="false" class="goods-iframe-wrapper"><iframe data-bjh-box="goods" data-goods-type="jingdong" data-goods-id="【gid】" data-goods-num_id="【num_id】" scrolling="no" frameborder="0" src="//baijiahao.baidu.com/builder/author/static/goods?id=【gid】" data-bjh-params="【商品卡源码】" class="edui-faked-goods" data-diagnose-id="174dd570c36379a49153045dfe2fa74d"></iframe></p><p><br></p>"""

    # global newTitle,title
    url = f'https://cecom.baidu.com/proxy/select/search_goods?access_name=cecom_fe&ak=cecom_fe&sign={baidu_getShop_sign(COOKIE)}'
    # print(url)
    html = wadeTools_Request.wade_Request_post(url=url,addHeader={'Accept': 'application/json',"Cookie": COOKIE,'Content-Type': 'application/json;charset=utf-8'},data=json.dumps({"keyWord":f"https://item.jd.com/{ITEM_ID}.html","categoryId1":0}))
    print(html.json())
    available = wadeTools_UserJSON.get_dict_by_key(find_keys='available',will_find_dist=html.json())
    commission = wadeTools_UserJSON.get_dict_by_key(find_keys='commission',will_find_dist=html.json())
    commission_rate = wadeTools_UserJSON.get_dict_by_key(find_keys='commission_rate',will_find_dist=html.json())
    coupon = wadeTools_UserJSON.get_dict_by_key(find_keys='coupon',will_find_dist=html.json())
    goods_id = wadeTools_UserJSON.get_dict_by_key(find_keys='goods_id',will_find_dist=html.json())
    imageList = wadeTools_UserJSON.get_dict_by_key(find_keys='imageList',will_find_dist=html.json())[0]
    is_commission = wadeTools_UserJSON.get_dict_by_key(find_keys='is_commission',will_find_dist=html.json())
    num_id = wadeTools_UserJSON.get_dict_by_key(find_keys='num_id',will_find_dist=html.json())
    originalGoodsId = wadeTools_UserJSON.get_dict_by_key(find_keys='originalGoodsId',will_find_dist=html.json())
    originalTitle = wadeTools_UserJSON.get_dict_by_key(find_keys='originalTitle',will_find_dist=html.json())
    platform = wadeTools_UserJSON.get_dict_by_key(find_keys='platform',will_find_dist=html.json())
    platformName = wadeTools_UserJSON.get_dict_by_key(find_keys='platformName',will_find_dist=html.json())
    price = wadeTools_UserJSON.get_dict_by_key(find_keys='price',will_find_dist=html.json())
    real_platform = wadeTools_UserJSON.get_dict_by_key(find_keys='real_platform',will_find_dist=html.json())
    saleNum = wadeTools_UserJSON.get_dict_by_key(find_keys='saleNum',will_find_dist=html.json())
    slink = wadeTools_UserJSON.get_dict_by_key(find_keys='slink',will_find_dist=html.json())
    title = wadeTools_UserJSON.get_dict_by_key(find_keys='title',will_find_dist=html.json())
    originalPrice="0"
    ubcPlatform="all"
    tab="goodsMall"
    query = slink
    fromdata = "baiduboxapp"
    newTitle = title[0:50]
    v="1.1"


    #提交商品
    url = "https://cecom.baidu.com/creator/dhGoodsAdd"
    postFORM = {
    "TPName": "",
    "activityName": "",
    "available": available,
    "commission": commission,
    "commission_rate": commission_rate,
    "coupon": coupon,
    "from": fromdata,
    "goods_id": goods_id,
    "imageList": imageList,
    "is_commission":is_commission,
    "newTitle": newTitle,
    "num_id": num_id,
    "originalGoodsId": originalGoodsId,
    "originalPrice": originalPrice,
    "originalTitle": originalTitle,
    "platform": platform,
    "platformName": platformName,
    "price": price,
    "query": query,
    "rankName": "",
    "real_platform": real_platform,
    "saleNum": saleNum,
    "slink": slink,
    "tab": tab,
    "title": title,
    "tpName": "",
    "ubcPlatform": ubcPlatform,
    "v": "1.1",

}

    html = wadeTools_Request.wade_Request_post(url=url,addHeader={"Referer": "https://cecom.baidu.com/m/shop/sdk/choosegoods/","Host": "cecom.baidu.com","Accept": "application/json","Content-Type": "application/x-www-form-urlencoded; charset=utf-8","Cookie": COOKIE},data=postFORM)


    print(postFORM)



    gid = wadeTools_UserJSON.get_dict_by_key(find_keys='gid',will_find_dist=html.json())
    #修改商品卡模板源码
    # global SHOP_CARD_CODE,SHOP_CARD_WEB_CODE
    SHOP_CARD_CODE = SHOP_CARD_CODE.replace('【gid】',gid).replace('【title】',title).replace('【new_title】',newTitle).replace('【image_list】',imageList).replace('【num_id】',num_id)
    SHOP_CARD_CODE = SHOP_CARD_CODE.replace('【price】',str(price)).replace('【slink】',str(slink)).replace('【platformName】',str(platformName)).replace('【commission】',str(commission)).replace('【saleNum】',str(saleNum))

    SHOP_CARD_WEB_CODE = SHOP_CARD_WEB_CODE.replace('【gid】',str(gid)).replace('【num_id】',str(num_id)).replace('【商品卡源码】',parse.quote(safe="",string=SHOP_CARD_CODE)).replace('【gid】',str(gid))
    # print("打印商品卡")
    # print(SHOP_CARD_CODE)
    # print("打印商品卡网页代码")
    # print(SHOP_CARD_WEB_CODE)
    print("生成商品卡...成功")
    return SHOP_CARD_WEB_CODE
'''发帖功能模块'''
def baiduPostContent(TITLE,CONTENT,COVER_IMG,COOKIE,TOKEN,ABSTRACT):
    # exit(code=0)
    from urllib import parse

    # exit(0)
    formData = {
        'type': 'news',
        'title': TITLE[0:30],
        'content': CONTENT,
        'abstract': ABSTRACT,
        'len': 27917,
        'activity_list%5B0%5D%5Bid%5D': 408,
        'activity_list%5B0%5D%5Bis_checked%5D': 1,
        'source_reprinted_allow': 0,
        'original_status': 0,
        'original_handler_status': 1,
        'isBeautify': 'false',
        'cover_layout': 'one',
        # 'cover_images': '''[{"src":"https://pic.rmb.bdstatic.com/bjh/news/95950f5a98b8b4346e386ba63f29e650.jpeg?x-bce-process=image/crop,w_719,h_479,x_0,y_16","cropData":{"x":0,"y":16,"width":719,"height":479},"machine_chooseimg":1,"isLegal":0}]''',
        'cover_images': f'''[{{"src":"{COVER_IMG}","cropData":{{"x":0,"y":16,"width":626,"height":417}},"machine_chooseimg":1,"isLegal":0}}]''',
        # '_cover_images_map':f"""[{"src":"https://pica.zhimg.com/50/v2-f78f790008da504b230ea3c28f8ef62e_720w.jpg?x-bce-process=image/crop,w_719,h_479,x_0,y_16","origin_src":"https://pic.rmb.bdstatic.com/bjh/news/95950f5a98b8b4346e386ba63f29e650.jpeg?x-bce-process=image/watermark,bucket_baidu-rmb-video-cover-1,image_YmpoL25ld3MvNjUzZjZkMjRlMDJiNjdjZWU1NzEzODg0MDNhYTQ0YzQucG5n,type_RlpMYW5UaW5nSGVpU01HQg==,w_19,text_QOeci-WoseS5kOivhOWFq-WNpg==,size_19,x_14,y_14,interval_2,color_FFFFFF,effect_softoutline,shc_000000,blr_2,align_1"}]""",
        '_cover_images_map':f"""[{{"src":"{COVER_IMG}","origin_src":"{COVER_IMG}"}}]""",
        'subtitle': "",
        'bjhtopic_id': "",
        'bjhtopic_info': "",
        'clue': 1,
        'bjhmt': "",
        'order_id': "",
        'image_edit_point': """%5B%7B%22img_type%22%3A%22cover%22%2C%22img_num%22%3A%7B%22template%22%3A0%2C%22font%22%3A0%2C%22filter%22%3A0%2C%22paster%22%3A0%2C%22cut%22%3A0%2C%22any%22%3A0%7D%7D%2C%7B%22img_type%22%3A%22body%22%2C%22img_num%22%3A%7B%22template%22%3A0%2C%22font%22%3A0%2C%22filter%22%3A0%2C%22paster%22%3A0%2C%22cut%22%3A0%2C%22any%22%3A0%7D%7D%5D""",
    }
    # print(formData)
    url= "https://baijiahao.baidu.com/pcui/article/publish?callback=_SAVE_PUBLISH_"  #发布
    # url= "https://baijiahao.baidu.com/pcui/article/save?callback=bjhdraft"  #草稿
    html = wadeTools_Request.wade_Request_post(url=url,addHeader={"Content-Type": "application/x-www-form-urlencoded","Cookie": COOKIE,"token":TOKEN},data=formData)
    # print(html.text)
    # print(html.json())
    return html.json()

def baiduPostContent_Caogao(TITLE,CONTENT,COVER_IMG,COOKIE,TOKEN,ABSTRACT):
    # exit(code=0)
    from urllib import parse

    # exit(0)
    formData = {
        'type': 'news',
        'title': TITLE[0:30],
        'content': CONTENT,
        'abstract': ABSTRACT,
        'len': 27917,
        'activity_list%5B0%5D%5Bid%5D': 408,
        'activity_list%5B0%5D%5Bis_checked%5D': 1,
        'source_reprinted_allow': 0,
        'original_status': 0,
        'original_handler_status': 1,
        'isBeautify': 'false',
        'cover_layout': 'one',
        # 'cover_images': '''[{"src":"https://pic.rmb.bdstatic.com/bjh/news/95950f5a98b8b4346e386ba63f29e650.jpeg?x-bce-process=image/crop,w_719,h_479,x_0,y_16","cropData":{"x":0,"y":16,"width":719,"height":479},"machine_chooseimg":1,"isLegal":0}]''',
        # 'cover_images': f'''[{{"src":"{COVER_IMG}?x-bce-process=image/crop,w_719,h_479,x_0,y_16","cropData":{{"x":0,"y":16,"width":719,"height":479}},"machine_chooseimg":1,"isLegal":0}}]''',
        'cover_images': f'''[{{"src":"{COVER_IMG}","cropData":{{"x":0,"y":16,"width":719,"height":479}},"machine_chooseimg":1,"isLegal":0}}]''',
        # '_cover_images_map':f"""[{"src":"https://pica.zhimg.com/50/v2-f78f790008da504b230ea3c28f8ef62e_720w.jpg?x-bce-process=image/crop,w_719,h_479,x_0,y_16","origin_src":"https://pic.rmb.bdstatic.com/bjh/news/95950f5a98b8b4346e386ba63f29e650.jpeg?x-bce-process=image/watermark,bucket_baidu-rmb-video-cover-1,image_YmpoL25ld3MvNjUzZjZkMjRlMDJiNjdjZWU1NzEzODg0MDNhYTQ0YzQucG5n,type_RlpMYW5UaW5nSGVpU01HQg==,w_19,text_QOeci-WoseS5kOivhOWFq-WNpg==,size_19,x_14,y_14,interval_2,color_FFFFFF,effect_softoutline,shc_000000,blr_2,align_1"}]""",
        # '_cover_images_map':f"""[{{"src":"{COVER_IMG}?x-bce-process=image/crop,w_719,h_479,x_0,y_16","origin_src":"{COVER_IMG}?x-bce-process=image/watermark,bucket_baidu-rmb-video-cover-1,image_YmpoL25ld3MvNjUzZjZkMjRlMDJiNjdjZWU1NzEzODg0MDNhYTQ0YzQucG5n,type_RlpMYW5UaW5nSGVpU01HQg==,w_19,text_QOeci-WoseS5kOivhOWFq-WNpg==,size_19,x_14,y_14,interval_2,color_FFFFFF,effect_softoutline,shc_000000,blr_2,align_1"}}]""",
        '_cover_images_map':f'''[{{"src":"{COVER_IMG}","origin_src":"{COVER_IMG}"}}]''',
        'subtitle': "",
        'bjhtopic_id': "",
        'bjhtopic_info': "",
        'clue': 1,
        'bjhmt': "",
        'order_id': "",
        'image_edit_point': """%5B%7B%22img_type%22%3A%22cover%22%2C%22img_num%22%3A%7B%22template%22%3A0%2C%22font%22%3A0%2C%22filter%22%3A0%2C%22paster%22%3A0%2C%22cut%22%3A0%2C%22any%22%3A0%7D%7D%2C%7B%22img_type%22%3A%22body%22%2C%22img_num%22%3A%7B%22template%22%3A0%2C%22font%22%3A0%2C%22filter%22%3A0%2C%22paster%22%3A0%2C%22cut%22%3A0%2C%22any%22%3A0%7D%7D%5D""",
    }
    # print(formData)
    # url= "https://baijiahao.baidu.com/pcui/article/publish?callback=_SAVE_PUBLISH_"  #发布
    url= "https://baijiahao.baidu.com/pcui/article/save?callback=bjhdraft"  #草稿
    html = wadeTools_Request.wade_Request_post(url=url,addHeader={"Content-Type": "application/x-www-form-urlencoded","Cookie": COOKIE,"token":TOKEN},data=formData)
    # print(html.text)
    # print(html.json())
    print(html.json()['errmsg'])

    return html.json()

if __name__ == '__main__':
    # 全局常量
    COOKIE = 'BIDUPSID=BE8639BCD6607F8E530A42EDF074C840; PSTM=1670469138; BAIDUID=BE8639BCD6607F8E1BE32DEFB23A5C7D:FG=1; BAIDUID_BFESS=BE8639BCD6607F8E1BE32DEFB23A5C7D:FG=1; BA_HECTOR=05248g0k218ha1208k0l2q8f1hp2lgi1h; ZFY=buAudwpR0vBRD6P5ezRDV9LQdhCmtYyBZgNKaXNUn:Bs:C; PSINO=1; delPer=0; BDORZ=B490B5EBF6F3CD402E515D22BCDA1598; BCLID=10829574753594179326; BDSFRCVID=ROFOJexroG0rxIcjuJUe5TwNmeKKv7TTDYrECenrWhab4-CVJeC6EG0PtEeydEu-EHtdogKKBeOTHg_F_2uxOjjg8UtVJeC6EG0Ptf8g0M5; H_BDCLCKID_SF=tR3a3RT_2RjsHJAk-4QEbbQH-UnLqhj93eOZ04n-ah02q4nV-P6hylL8jJOfWtr-W23q_Mbm3UTKsqONhR5RM-_Vj2cmLfT-0bc4KKJxbp5qJJbH5Dcpyb0OhUJiBMj-Ban70M7IXKohJh7FM4tW3J0ZyxomtfQxtNRJ0DnjtpChbRO4-TFhe5oQDMK; BDSFRCVID_BFESS=ROFOJexroG0rxIcjuJUe5TwNmeKKv7TTDYrECenrWhab4-CVJeC6EG0PtEeydEu-EHtdogKKBeOTHg_F_2uxOjjg8UtVJeC6EG0Ptf8g0M5; BCLID_BFESS=10829574753594179326; H_BDCLCKID_SF_BFESS=tR3a3RT_2RjsHJAk-4QEbbQH-UnLqhj93eOZ04n-ah02q4nV-P6hylL8jJOfWtr-W23q_Mbm3UTKsqONhR5RM-_Vj2cmLfT-0bc4KKJxbp5qJJbH5Dcpyb0OhUJiBMj-Ban70M7IXKohJh7FM4tW3J0ZyxomtfQxtNRJ0DnjtpChbRO4-TFhe5oQDMK; PHPSESSID=v5nh9lmql6vif1fjq803stu1l1; RECENT_LOGIN=1; canary=0; gray=1; Hm_lvt_f7b8c775c6c8b6a716a75df506fb72df=1670469313; browserupdateorg=pause; BDRCVFR[feWj1Vr5u3D]=I67x6TjHwwYf0; H_PS_PSSID=37858_36557_37690_37910_37765_37759_37904_26350_22158_37881; BDUSS_BFESS=Edud3NHbVdRZ2p0M295U2lHZ2xsWmg1cVJ2bFdHdlJvbjlBZmVQUWlsZ1pHN2xqRVFBQUFBJCQAAAAAAAAAAAEAAACQvPM4u6jT0LDZ0fnAogAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAABmOkWMZjpFjZ; BDUSS=Edud3NHbVdRZ2p0M295U2lHZ2xsWmg1cVJ2bFdHdlJvbjlBZmVQUWlsZ1pHN2xqRVFBQUFBJCQAAAAAAAAAAAEAAACQvPM4u6jT0LDZ0fnAogAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAABmOkWMZjpFjZ; Hm_lpvt_f7b8c775c6c8b6a716a75df506fb72df=1670483779; RT="z=1&dm=baidu.com&si=372c7e8a-5a20-4b61-9c58-4522f1ce78af&ss=lbeiapya&sl=18&tt=2wgg&bcn=https%3A%2F%2Ffclog.baidu.com%2Flog%2Fweirwood%3Ftype%3Dperf"; ab_sr=1.0.1_MWEzMmQ5MzdhMmUxMDU5ZTExOTM3MWViNjIxMGI5ODFkOWM3YmZhMWQ2NjFlZmU5NDQyOTdjMjQ3MTM1ZjFhOWQ3MDljZTkwYzVjMjczY2RhNjQ5NzhhZWU3ZTk3YWE0ZjE4OTQ2NmZlZDMwZThiYzVhMzk1ZGZkOTlkMDIxZDRhYmVhOTFmZmRhMGQ5OTQ1YmI3NGI2ZTAxMGJmZjcxOQ==; devStoken=901516d0ad6212f1fbf1a0fcf039a7214364508e0e705efa88a98a7c5faf1257; bjhStoken=1ae176cca6bbb7980847e9932c9524364364508e0e705efa88a98a7c5faf1257'
    TOKEN = 'eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJpc3MiOiJodHRwOlwvXC9iYWlqaWFoYW8uYmFpZHUuY29tIiwiYXVkIjoiaHR0cDpcL1wvYmFpamlhaGFvLmJhaWR1LmNvbSIsImlhdCI6MTY3MDQ4Mzc4NSwibmJmIjoxNjcwNDQwNTkwLCJleHAiOjE2NzA1MjY5OTB9.UTPXv_fiz1cc7ZcSWV4XwZYvJhi4F1rwcOOGBtCp3Lk'
    ABSTRACT = "我是简介"
    PUBLIST_NUM = 0
    TITLE = f"测试内容的时候，一定要善待键盘"
    CONTENT = f"""<tbody data-diagnose-id="e2f77d464f1fe15541239a7b11fad887"><tr class="firstRow" data-diagnose-id="988b2537036a1b1bbd1ea6d8db17a954"><td width="90" style="word-break: break-all" data-diagnose-id="afc3729b74329c22fd335dbcccd2facf">&#8203;<br></td><td width="90" data-diagnose-id="c96905aa0bd9d8dd86005973f35cf12d"><br></td><td width="90" data-diagnose-id="e8c9e47f4fd9b2ce9bceb741a20f4677"><br></td><td width="90" data-diagnose-id="597ca2910f24e7c4d687eff34fb2b475"><br></td></tr><tr data-diagnose-id="8ee869f95815db1e1b1dae5fcac9dd5c"><td width="90" data-diagnose-id="818d94053470ad80e9ed7dc545dda194"><br></td><td width="90" data-diagnose-id="7390ccecd42f0f96c24cf8f027a8e046"><br></td><td width="90" data-diagnose-id="a63afc6e08e6d5f2443c236a7cedf5d6"><br></td><td width="90" data-diagnose-id="b453ea1be0a90b00c930c8125f842804"><br></td></tr><tr data-diagnose-id="0c5475b8ffda97775a293bbd8f95cf67"><td width="90" data-diagnose-id="8c72ff6e89952f57e300e77e8faa6cfa"><br></td><td width="90" data-diagnose-id="2aa58573aa43b64e98c8f4e04fbb53ae"><br></td><td width="90" data-diagnose-id="99f2a61ee6c9ebfe0fe57ed006141b71"><br></td><td width="90" data-diagnose-id="82b7d2629085bb170b52e76def72475e"><br></td></tr></tbody><p>aaaaaaaaaaaaaaaaaaaaaaaaaaaa</p>【商品卡】<p>测试测试测试测</p><p data-bjh-caption-id="cap-62857951" class="bjh-image-container cant-justify" data-bjh-helper-id="1649741270711" data-bjh-caption-text="" data-bjh-caption-length="16"><img src="https://pic.rmb.bdstatic.com/bjh/news/95950f5a98b8b4346e386ba63f29e650.jpeg?x-bce-process=image/watermark,bucket_baidu-rmb-video-cover-1,image_YmpoL25ld3MvNjUzZjZkMjRlMDJiNjdjZWU1NzEzODg0MDNhYTQ0YzQucG5n,type_RlpMYW5UaW5nSGVpU01HQg==,w_19,text_QOeci-WoseS5kOivhOWFq-WNpg==,size_19,x_14,y_14,interval_2,color_FFFFFF,effect_softoutline,shc_000000,blr_2,align_1" data-bjh-origin-src="https://pic.rmb.bdstatic.com/bjh/news/95950f5a98b8b4346e386ba63f29e650.jpeg" data-bjh-type="IMG" data-bjh-params="%7B%22org_url%22%3A%22https%3A%2F%2Fpic.rmb.bdstatic.com%2Fbjh%2Fnews%2F95950f5a98b8b4346e386ba63f29e650.jpeg%22%7D" data-diagnose-id="88ffc2da7feca8d68e5c9ff3586b6604" data-w="719" data-h="540"></p><p><br></p>"""

    # baiduInit(COOKIE=COOKIE)
    # print(PUBLIST_NUM)
    # baiduImageUrl(COOKIE=COOKIE)  #转换图片链接
    SHOP_CARD_WEB_CODE = baidu_selectShopItem(COOKIE=COOKIE,ITEM_ID=100021771660)  #插入商品卡
    # baiduPostContent_Caogao(CONTENT=CONTENT.replace('【商品卡】',SHOP_CARD_WEB_CODE),TITLE=TITLE,COVER_IMG='',COOKIE=COOKIE,TOKEN=TOKEN,ABSTRACT=ABSTRACT)   #发布文字
    # print(SHOP_CARD_WEB_CODE)


import re

from chardet.universaldetector import UniversalDetector

'''by：shenhuawade
qq: 317909531
功能：自动判断txt的编码格式，都自动转换成utf8编码

readtextMain(filename)
------------------------------------------
输入参数filename: 文件名 '游记：皮尔森啤酒博物馆.txt'
-------------------------------------------
输出参数list: 每行文字组成的列表

------------------------------------------
code/time:2019.1.5
'''


def readText(file,encode_info):
    # 2.按行读取
    textlist =[]
    mylen = 0
    for line in open(file, errors='ignore',encoding=encode_info):
        # 清洗空格后如果不为空就下一步处理
        if line.strip() != '':
            # print(f"本行内容为{line}")
            # 每行的数据都需要清洗空格后进行下一步处理
            abc = line.strip()
            mylen = mylen+len(abc)

            if mylen <= 9900:
                textlist.append(abc)
            else:
                break
        else:
            # print("本行为空")
            pass
    print(mylen)
    return textlist




def get_encode_info(file):
    with open(file, 'rb') as f:
        detector = UniversalDetector()

        for line in f.readlines():
            # print(line)
            detector.feed(line)
            if detector.done:
                break
        detector.close()
        # print(detector.result['encoding'])
        if detector.result['encoding'] == None:
            return 'ascii'
        return detector.result['encoding']


def read_file(file):
    with open(file, 'rb') as f:
        return f.read()


def write_file(content, file):
    with open(file, 'wb') as f:
        f.write(content)


def convert_encode2utf8(file, original_encode, des_encode):
    file_content = read_file(file)
    print(file_content)
    file_decode = file_content.decode(original_encode, 'ignore')
    file_encode = file_decode.encode(des_encode)
    write_file(file_encode, file)



#核心函数
def readtextMain(filename):
    filename = rf'{filename}'
    file_content = read_file(filename)
    encode_info = get_encode_info(filename)
    if encode_info != 'utf-8':
        convert_encode2utf8(filename, encode_info, 'utf-8')
    encode_info = get_encode_info(filename)
    print(encode_info)
    textlist = readText(filename, encode_info)
    return textlist

def paragraph_To_LimiteWordNUM_List(paragraph,limitNum):
    # paragraph = """etc全称Electronic Toll Collection，意思是全自动电子收费系统，是国际上正在努力开发并推广的一种用于公路、大桥和隧道的电子自动收费系统，是智能交通系统的服务功能之一。
    # etc采用车辆自动识别技术完成车辆与收费站之间的无线数据通讯，进行车辆自动感应识别和相关收费数据的交换，运用计算机网络进行收费数据的处理，不停车、不设收费窗口，实现自动收费。
    # etc收费系统每车收费耗时不到两秒，其收费通道的通行能力是人工收费通道的5至10倍。此外，etc还可以使公路收费走向无纸化、无现金化管理，从根本上杜绝收费票款的流失现象，解决公路收费中的财务管理混乱问题；另外，实施etc还能够节约基建费用和管理费用。
    # """
    # result_list = re.split(r'[。\s]', paragraph)  按句号和空格分开
    result_list = re.split(r'[。]', paragraph)   #按句号分隔
    # print(result_list)

    for index,item in enumerate(result_list):
        result_list[index] = item.strip()
    result_list = [i+"。" for i in result_list if i != '']
    print(result_list)
    return result_list

if __name__ == "__main__":

    # filename = r'C:\xiaohuohua\AAAVIP工具箱\VIPtool\疯狂动物城：A movie about growth an.txt'
    # textlist = readtextMain(filename)
    # print(textlist)
    paragraph = """etc全称为Electronic Toll Collection ，是电子不停车收费系统，也就是在高速公路或桥梁上对装了ETC车载器的车辆进行自动收费。
电子不停车收费系统通过安装在车辆挡风玻璃上的车载电子标签与在收费站 etc 车道上的微波天线之间进行的专用短程通讯，利用计算机联网技术与银行进行后台结算处理，从而达到车辆通过高速公路或桥梁收费站无需停车而能交纳高速公路或桥梁费用的目的。
    """
    paragraph_To_LimiteWordNUM_List(paragraph,limitNum=300)
















def baiduORC_API(path):
    # python百度ai的身份证识别代码
    # pip install baidu-aip
    from aip import AipOcr
    # 定义常量
    APP_ID = '10736496'  # 你百度帐号上的APP_ID
    API_KEY = 'xLwFVx76ZmGujNxFGSGp8wUc'  # 你百度帐号上的API_KEY
    SECRET_KEY = 'H6jpVPX3wRdcxKf59r0qoGvG6zfHnMEk'  # 你百度帐号上的SECRET_KEY

    # 初始化AipFace对象
    client = AipOcr(APP_ID, API_KEY, SECRET_KEY)

    """ 读取图片 """

    def get_file_content(filePath):
        with open(filePath, 'rb') as fp:
            return fp.read()

    image = get_file_content(path)  # 将左侧括号内1.jpg替换为待识别的图片路径

    try:
        # print(type(image))
        """ 调用身份证识别 """
        result = client.basicGeneral(image)
        print(result)

        # if result["words_result"]["公民身份号码"]["words"] =="":
        #     return None
        # else:
        #     # print("姓名：", result["words_result"]["姓名"]["words"])
        #     # print("性别：", result["words_result"]["性别"]["words"])
        #     # print("民族：", result["words_result"]["民族"]["words"])
        #     # print("生日：", result["words_result"]["出生"]["words"])
        #     # print("身份证号：", result["words_result"]["公民身份号码"]["words"])
        #     # print("住址：", result["words_result"]["住址"]["words"])
        #     return result
    except Exception as e:
        print(e)

baiduORC_API('fenlei2.png')

'''
1.国际
2.体育
3.娱乐
4.社会
5.财经
6.互联网
7.科技
8.房产
9.汽车
10.教育
11.时尚
12.游戏
13.军事
14.旅游
15.生活
16.创意
17.搞笑
18.美图
19.女人
20.美食
21.家居
22.健康
23.两性
24.情感
25.育儿
26.文化
27.历史
28.宠物
29.科学
30.动漫
31.职场
32.三农
33.悦读
34.辟谣



'''


# -*- encoding=utf-8 -*-

# 打印的升级版
import sys
def wadePrint(msg,*args):
    print(f'\033[0;36m{msg}',*args, '\033[0m   \033[0;37m ',sys._getframe(1).f_code.co_filename, sys._getframe(1).f_lineno,'\033[0m')
def wadeBluePrint(msg,*args):
    print(f'\033[0;36m{msg}',*args, '\033[0m   \033[0;37m ','\033[0m')
def wadeRedPrint(msg,*args):
    print(f'\033[0;31m{msg}',*args, '\033[0m   \033[0;37m ',sys._getframe(1).f_code.co_filename, sys._getframe(1).f_lineno,'\033[0m')

if __name__ == '__main__':
    wadeRedPrint(1,3,4)
    wadeBluePrint(1,3,4)



"""
保存日志文档：
saveLog()
显示实时日志
showLOG(msg,self.text类型)

#保存listBox对象内容
saveListbox(ListBox对象)

#加载listBox对象内容
readListbox(ListBox对象)
"""
import pickle
import sys
import tkinter as tk
from tkinter import filedialog, messagebox
from wadeTools import wadeTools_ReadAndWrite, wadeTools_encodingTxt, wadeTools_readConfig_ini, wadeTools_TkinterClass
from tkinter import filedialog
from tkinter import ttk
import re
import traceback

class WadeApplication():
    def __init__(self):

        self.initData = wadeTools_readConfig_ini.ReadConfig('config.ini')
        self.window = tk.Tk()
        self.window.geometry()
        self.log_line_num = 0
        self.window.grid()
        self.create_widgets()
        self.window.mainloop()

    def create_widgets(self):
        self.window.protocol("WM_DELETE_WINDOW", self.on_closing)

        self.menubar = tk.Menu(self.window)
        # 创建一个下拉菜单“文件”，然后将它添加到顶级菜单中
        self.filemenu = tk.Menu(self.menubar, tearoff=False)
        self.filemenu.add_command(label="打开", command=self.openFile)
        self.filemenu.add_command(label="作者", command=lambda: self.message_showinfo())  # 如果没有lambda:  那么传参模式打开窗口就会调用
        self.menubar.add_cascade(label="文件", menu=self.filemenu)  # 将filemenu加入到顶级菜单menubar
        # 显示菜单
        self.window.config(menu=self.menubar)
        # 软件标志
        self.lable_title = tk.Label(self.window, text="欢迎使用高级协议VIP")
        self.lable_title.grid(row=0, column=0, pady=2)

        # 完整的软件列表内容
        self.canvas1 = tk.Canvas(self.window, relief=tk.FLAT, background="#D2D2D2")
        self.canvas1.grid(row=1, column=0, sticky=tk.EW)
        # 滚动条,先渲染列表，然后 把滚动条覆盖在右侧，联动列表内容
        self.listBox1 = tk.Listbox(self.canvas1)
        self.listBox1.grid(row=1, column=1)
        self.scrool_Bar1 = tk.Scrollbar(self.canvas1)
        self.scrool_Bar1.grid(row=1, column=2, sticky=tk.N + tk.S + tk.E)  # N+S上下伸展 E靠右放置  E+W左右伸展  S靠下放置
        self.scrool_Bar1.configure(command=self.listBox1.yview)
        self.listBox1.configure(yscrollcommand=self.scrool_Bar1.set)

        self.button1 = ttk.Button(self.canvas1, text="开始", command=self.startNOW)
        self.button1.grid(row=7, column=1, sticky=tk.W)
        self.button1 = ttk.Button(self.canvas1, text="删除第一条", command=self.delListBoxFirstOne)
        self.button1.grid(row=7, column=1, sticky=tk.E)
        self.readListbox(self.listBox1)

        self.listBox2 = tk.Listbox(self.window)
        self.listBox2.grid()
        self.readListbox(self.listBox2)
        self.button2 = tk.Button(self.window, text="开始2", command=self.startNOW1)
        self.button2.grid()

        # 左日志文本框
        self.logText = tk.Text(self.window, width=130, height=9)  # 日志框
        self.logText.grid()

    def readWord(self, path):  # 根据路径读取内容
        sec_user_id_List = wadeTools_encodingTxt.readText(path, 'UTF-8')
        return sec_user_id_List

    def openFile(self):  # 打开文件，获取路径
        # 选择文件  返回文件路径
        self.filePath = filedialog.askopenfilename(title="打开文件~~只能是txt文本哦",
                                                   filetypes=(("txt files", "*.txt"),))  # 只能选择单个文件
        fileContentList = self.readWord(self.filePath)
        for num, i in enumerate(fileContentList, start=1):
            self.listBox1.insert(tk.END, f"{i}", )  # END表示最后一个位置插入
        return

    def saveLog(self, msg):
        wadeTools_ReadAndWrite.saveLog(msg)

    def readLog(self):  # return list
        return wadeTools_ReadAndWrite.readLog()

    # 保存列表内容，给一个列表对象，就能实时保存列表内容和读取，直接加载到列表中
    def saveListbox(self, listBox_OBJ):

        stack = traceback.extract_stack()
        filename, lineno, function_name, code = stack[-2]
        vars_name = re.compile(r'\((.*?)\).*$').search(code).groups()[0]
        listBox_OBJ_Name = vars_name.replace('self.', '')

        # print(sys._getframe().f_back.f_locals[listBox_OBJ])
        # print(list(dict(listBox_OBJ=listBox_OBJ).keys())[0])  #获取属性自己的变量名称

        # 构造存储字典：
        # 总字典
        try:
            dataDict = wadeTools_ReadAndWrite.wadeRead('obj.data', 'rb')
        except:
            dataDict = {}
        dataDict[listBox_OBJ_Name] = listBox_OBJ.get(first=0, last=tk.END)
        with open("obj.data", "wb") as fout:
            pickle.dump(dataDict, fout)
        fout.close()
        del dataDict

    def readListbox(self, listBox_OBJ):
        try:

            stack = traceback.extract_stack()
            filename, lineno, function_name, code = stack[-2]
            vars_name = re.compile(r'\((.*?)\).*$').search(code).groups()[0]
            listBox_OBJ_Name = vars_name.replace('self.', '')
            dataDict = wadeTools_ReadAndWrite.wadeRead('obj.data', 'rb')

            listBox_OBJ_List = dataDict[listBox_OBJ_Name]
            for num, i in enumerate(listBox_OBJ_List, start=1):
                listBox_OBJ.insert(tk.END, f"{i}", )  # END表示最后一个位置插入
            del dataDict
        except:
            print("缺少obj.data文件")
        return

    def delListBoxFirstOne(self):  # 删除第一条

        self.saveListbox(self.listBox1)
        self.listBox1.delete(0)

    def startNOW(self):

        self.listBox1.insert(tk.END, self.log_line_num)
        self.showLOG('111', self.logText)

    def startNOW1(self):
        self.listBox2.insert(tk.END, 222)
        self.saveListbox(self.listBox2)
        self.showLOG('111', self.logText)

    def changeColor(self, color="red"):
        # print(self.listbox1.get(first=0, last=tk.END))

        self.listbox1.itemconfig(0, bg=color)  # 标注颜色
        return

    # 运行日志处理函数
    def showLOG(self, logmsg, textOBJ):
        logmsg_in = f"{wadeTools_ReadAndWrite.get_current_time()}:{logmsg}\n"  # 换行
        if self.log_line_num <= 7:
            textOBJ.insert(tk.END, logmsg_in)
            self.log_line_num = self.log_line_num + 1
        else:
            textOBJ.delete(1.0, 2.0)
            textOBJ.insert(tk.END, logmsg_in)

    # 提醒模组
    def message_showinfo(self, title="秘境", msg="我是一个风尘少年，归隐于无形"):
        # 弹出消息,result返回true或者false
        # result = tkinter.messagebox.showinfo(title='秘境', message='我是一个风尘少年，归隐于无形')
        result = tk.messagebox.showinfo(title=title, message=msg)

    def message_askokcancel(self, title="秘境", msg="我是一个风尘少年，归隐于无形"):
        # 弹出对话框,result返回true或者false
        result = tk.messagebox.askokcancel(title=title, message=msg)

    def message_askquestion(self, title="秘境", msg="我是一个风尘少年，归隐于无形"):
        # 弹出对话框,result返回true或者false
        result = tk.messagebox.askquestion(title=title, message=msg)

    def message_askyesno(self, title="秘境", msg="我是一个风尘少年，归隐于无形"):
        # 弹出对话框,result返回true或者false
        result = tk.messagebox.askyesno(title=title, message=msg)

    def message_showerror(self, title="秘境", msg="我是一个风尘少年，归隐于无形"):
        # 弹出对话框,result返回true或者false
        result = tk.messagebox.showerror(title=title, message=msg)

    # 关闭模组：
    def on_closing(self):
        if tk.messagebox.askokcancel("Quit", "Do you want to quit?"):
            self.window.destroy()

class mywin(wadeTools_TkinterClass.WadeApplication):
    #写布局
    def create_widgets(self):
        """
        这里写布局，self.windows是根窗口
        :return:
        """
        return

    def method(self):
        """
        这里写方法，着是方法1，对应窗口内容
        :return:
        """
        return
    #写方法，不用管其他的了

if __name__ == '__main__':
    mywin = WadeApplication()








# coding: utf-8
#adb控制手机的必备小刀
import os
import time

"""
看到某个关键词就做出指定动作：watchText
死等某个关键词出现后在继续下一步操作 waitText
向手机送文件：addFileToAndroid
删除手机中的文件：delFileFromPhone

开启driver  
--------------------------------------------------------
import uiautomator2 as u2
driver = u2.connect_usb()
--------------------------------------------------------
具体配置看石墨就行
"""

def checkExists(driver,text):
    """
    查询页面上是否存在这个文本
    :param text:
    :return:
    """
    if driver.xpath(f'//*[@text="{text}"]').exists == True:
        return True
    else:return False
def waitText(driver,text):
    """
    （死等）在一定时间内等待文本出现
    :param driver:
    :param text:
    :return:
    """
    while (checkExists(driver, text)==False):  #
        print(f"等待字符....：{text}，出现.......")
        time.sleep(1)


def watchText(driver,text,action):
    """
    看到这个文本就执行某个操作
    :param driver:
    :param text:
    :return:
    d.press("back")  # 点击back键
    d.press("home")  # 点击home键
    d.press("left")  # 点击左键
    d.press("right")  # 点击右键
    d.press("up")  # 点击上键
    d.press("down")  # 点击下键
    d.press("center")  # 点击中间
    d.press("menu")  # 点击menu按键,菜单键
    d.press("search")  # 点击搜索按键
    d.press("enter")  # 点击enter键，键盘上的Enter键
    d.press("delete")  # 点击删除按键，delete（or del)对应键盘上的DEL键 用于删除）
    d.press("recent")  # 点击近期活动按键,(recent apps)
    d.press("volume_up")  # 音量+
    d.press("volume_down")  # 音量-
    d.press("volume_mute")  # 静音
    d.press("camera")  # 相机拍照按钮
    d.press("power")  # 电源键

    """
    while (checkExists(driver, text)==True):  #
        print(f"观察到：{text}，执行动作：{action}")
        driver.press(f"{action}")
        time.sleep(2)




def addFileToAndroid(driver,fileName,filepath,android_directory_name):
    """
    将windows下的文件推到模拟器文件夹里，输入保存得文件名和哪个文件夹目录下
    :param fileName: windos中选择的文件名
    :param filepath: windos中选择的文件的绝对路径
    :param directory_name: 目标文件夹：Movies就是放到movies文件夹，dicm就是放在dicm文件夹里  android_directory_name = 'Movies'
    :return:
    """
    driver.push(os.path.join(filepath,fileName), f"/sdcard/{android_directory_name}/")  #推送文件到movie文件夹，savepath="/sdcard/Movies/"
    #一定要广播
    driver.shell(f'am broadcast -a android.intent.action.MEDIA_SCANNER_SCAN_FILE -d file:///storage/emulated/0/{android_directory_name}/{fileName}')
    time.sleep(1)

def delFileFromPhone(driver,fileName,android_directory_name):
    """
    删除模拟器文件夹里文件删除，文件名和哪个文件夹目录下
    :param fileName:
    :param directory_name:Movies就是放到movies文件夹，dicm就是放在dicm文件夹里
    :return:
    """
    driver.shell(f'rm /sdcard/{android_directory_name}/{fileName}')  # 删除文件
    #一定要广播，安卓里边需要这个内容，不用懂
    driver.shell(f'am broadcast -a android.intent.action.MEDIA_SCANNER_SCAN_FILE -d file:///storage/emulated/0/{android_directory_name}/{fileName}')
    time.sleep(1)



import sqlite3
# commit()--事务提交
# rollback()--事务回滚
# close()--关闭一个数据库连接
# cursor()--创建一个游标


# INTEGER 整数 ， REAL 浮数 ， TEXT 字符串 ， unique 唯一

class wadeDb():
    def __init__(self,dbFilePath,tableName,typeList=({"字段名":"ID","字段类型":"TEXT unique"},{"字段名":"状态","字段类型":"TEXT"})): # dbFilePath="J:/wade.db",tableName="happy"
        self.dbFilePath = dbFilePath
        self.tableName = tableName
        self.conn = sqlite3.connect(self.dbFilePath)
        self.cursor = self.conn.cursor()
        self.typeList =typeList

    # 判断记录是否存在，返回bool
    def checkExist(self,keyName,value):
        results =self.cursor.execute(f"SELECT 1 FROM {self.tableName} WHERE {keyName} = {value} LIMIT 1")

        # print(results.fetchone())
        if results.fetchone() == None:
            return False
        else:return True

    # 创建表
    def initdb(self):
        sql = ''
        for item in self.typeList:
            # print(item)
            sql = sql + f"'{item.get('字段名')}' {item.get('字段类型')},"
        sql = sql.rstrip(',')
        # print(sql)
        create_table_sql = f'''create table IF NOT EXISTS {self.tableName}(
                            {sql}
                            )'''
        # create_table_sql = f'''create table IF NOT EXISTS {self.tableName}(
        #                             'ID' INTEGER unique,
        #                             '状态' INTEGER
        #                             )'''
        self.cursor.execute(create_table_sql)  # 执行这个语句
    # #
    def addParam(self,TableParamData:tuple):
        """新增字段，要求输入TableParamData=（列的名字，列的类型，默认值）"""
        print(TableParamData)
        try:
            self.cursor.execute(
                f"""ALTER TABLE {self.tableName} ADD COLUMN {TableParamData[0]} {TableParamData[1]} DEFAULT {
                TableParamData[2]} """)

            self.conn.commit()
        except sqlite3.OperationalError as e:
            print('数据库Exception提醒：',e)
    def getTablePrarm(self):
        # 返回该表的所有表的标题行字段内容和类型
        self.cursor.execute(f"""SELECT name, type FROM pragma_table_info('{self.tableName}')""")
        table_typeList = self.cursor.fetchall()

        table_typeList_tupe = []
        for item in table_typeList:
            table_typeList_itemJSON={}
            table_typeList_itemJSON["字段名"] = item[0]
            table_typeList_itemJSON["字段类型"] = item[1]
            table_typeList_tupe.append(table_typeList_itemJSON)
        table_typeList_tupe = tuple(table_typeList_tupe)
        # print(table_typeList_tupe)
        self.conn.commit()
        return table_typeList_tupe
    #增
    def insertdb(self,insertData:tuple):
        # 二、插入数据：执行语句即可由相同唯一列如果存在，就不会插入,
        # self.cursor.execute("insert into test (id,name,age) values (?,?,?);", [(1, 'abc', 15), (2, 'bca', 16)])
        sql1 = []
        for item in self.getTablePrarm():
            print(item)
            sql1.append(item.get('字段名'))
        sql1 = str(tuple(sql1))
        # print(sql1)
        insert_data_sql = f'''insert or ignore into {self.tableName}{sql1} values {insertData}'''
        # print(insert_data_sql)
        self.cursor.execute(insert_data_sql)
        self.conn.commit()
    # 关闭数据库
    def closedb(self,conn):
        self.conn.commit()
        self.cursor.close()

    # 查询表内所有数据
    def searchdb(self):
        '''查询所有语句，返回数据库所有内容'''
        sql = ''
        for item in self.getTablePrarm():
            # print(item)
            sql = f"'{item.get('字段名')}'," + sql
        sql = sql.rstrip(',').replace("'",'')
        search_sql = f"select {sql} from {self.tableName}"
        # print(search_sql)
        results = self.cursor.execute(search_sql)
        all_results = results.fetchall()
        # for row in all_results:
        #     print(type(row))  # type:tuple
        #     print(list(row))  # type:list
        return all_results
    # 根据表头和1种内容查询表内符合的数据,或者判断是否存在
    def searchAll_byKeyName(self,keyName,value):
        '''查询语句，返回符合条件的所有内容'''
        search_sql = f"SELECT * FROM {self.tableName} WHERE {keyName} = {value}"
        results = self.cursor.execute(search_sql)
        all_results = results.fetchall()
        # print(all_results)
        # for row in all_results:
            # print(type(row))  # type:tuple
            # print(list(row))  # type:list
        return all_results

    # 根据表头和2列内容查询表内符合的数据,或者判断是否存在
    def searchAll_byTwoKeyName(self,keyName1,value1,keyName2,value2):
        '''查询语句，返回符合条件的所有内容'''
        search_sql = f"SELECT * FROM {self.tableName} WHERE {keyName1} = {value1} and {keyName2} = {value2}"
        results = self.cursor.execute(search_sql)
        all_results = results.fetchall()
        # print(all_results)
        # for row in all_results:
            # print(type(row))  # type:tuple
            # print(list(row))  # type:list
        return all_results

        # 根据根据某个对应的值，查出想要的字段的值得里列表
    def searchNeedValue_byKeyName(self, keyName, value,needKeyName):
        """
        :param keyName: 拿来查询的字段名
        :param value:   拿来查询的索引
        :param needKeyName:   想要查询出的数据
        :return: None,Tuple
        """
        '''查询语句，返回符合条件的所有内容'''
        search_sql = f"SELECT {needKeyName} FROM {self.tableName} WHERE {keyName} = {value}"
        results = self.cursor.execute(search_sql)
        # all_results = results.fetchone()
        # print(all_results)
        # if all_results == None:
        #     return "用来查询的值不存在"
        # print(all_results)
        all_results=[]
        for row in results:
            all_results.append(row[0])
        return all_results

    #删除表内字段名符合条件的所有内容    delete(cursor,'588976817331')
    def deleteItem(self,keyName,value):
        """
        删除 符合条件的一行所有内容
        :param keyName: 指定根据哪个字段来说删除
        :param value:   字段对应的内容
        :return: None
        """
        delete_sql = f'''delete from {self.tableName} where "{str(keyName)}" = "{value}" '''
        print(delete_sql)
        self.cursor.execute(delete_sql)
        self.conn.commit()

    # 删除一整个表格    deleteTable(cursor, "happy")
    def deleteTable(self, tablename):
        check = eval(input(f"请输入四个数字8来确认删除表【{tablename}】:\n"))
        if check == 8888:
            delete_all_sql = f'drop table {self.tableName}'
            self.cursor.execute(delete_all_sql)
            self.conn.commit()
            print("数据表",tablename,"删除成功")
        else:
            print("对不起，输入有误")
    # 修改内容，只要符合的全部都会修改，只有修改唯一值，才能保证只改一行，否则所有符合条件的行都会被修改
    def updateValue(self,byKey,byKey_value,changeKey,changeKey_value):
        update_sql = f'update {self.tableName} set {changeKey}=? where {byKey}=?'
        self.cursor.execute(update_sql, (changeKey_value, byKey_value))
        self.conn.commit()
        print("修改数据成功")

    # 在表中随机取符合条件的一条
    def getOne(self,keyName,value):
        update_sql = f'SELECT *  FROM {self.tableName} WHERE {keyName} = {value} ORDER BY RANDOM() limit 1'
        results = self.cursor.execute(update_sql)
        self.conn.commit()
        result = results.fetchone()
        return result

    # 在表中随机取符合两个条件的一条
    def getOneByTwoKeys(self, keyName1, value1,keyName2,value2):
        update_sql = f'SELECT *  FROM {self.tableName} WHERE ({keyName1} = {value1}) and ({keyName2} = {value2}) ORDER BY RANDOM() limit 1'
        results = self.cursor.execute(update_sql)
        self.conn.commit()
        result = results.fetchone()
        return result
    def closeDb(self):
        self.cursor.close()
        self.conn.close()

    # 直接运行语句，返回结果中的一个
    def runSQLite(self,SQL):
        results = self.cursor.execute(SQL)
        self.conn.commit()
        result = results.fetchone()
        return result
    # 直接运行语句,返回所有结果
    def runSQLite_mode2(self,SQL):
        results = self.cursor.execute(SQL)
        self.conn.commit()
        return results
if __name__ == '__main__':
    """使用方法 创建表 新增字段  表的增删查改"""
    # 创建表，要写清楚字段格式
    from wadeTools import wadeTools_db_Sqlite

    mySql = wadeTools_db_Sqlite.wadeDb(dbFilePath="data.db", tableName='jdTable', typeList=(
        {"字段名": "字段标题1", "字段类型": "TEXT unique"},
        {"字段名": "字段标题2", "字段类型": "TEXT"},
    ))
    mySql.initdb()
    # a = mySql.getOne(keyName='字段标题2',value='22')
    a = mySql.getOneByTwoKeys(keyName1='字段标题2',value1='22',keyName2='字段标题1',value2="22")
    print(a)
    exit()

    # 新增字段，范例中创建了字段名是“姓名”，类型是TEXT，默认值是空
    mySql.addParam(TableParamData=("姓名", 'TEXT',"1"))

    # 增加一条数据 新增一条数据
    mySql.insertdb(("你好", 23, "123"))
    mySql.insertdb(("JDID2121", 23, "123"))
    mySql.insertdb(("JDID212231", 23, "123"))

    # 删除一条数据
    mySql.deleteItem(keyName="字段标题1",value="你好")

    # 删除某个数据表：
    mySql.deleteTable("jdTable")
    # 查询表内所有数据
    print(mySql.searchdb())

    # 查询 符合某个值内容的所有行
    print(mySql.searchAll_byKeyName(keyName="姓名",value="123"))

    # 查询 场景：我想要表内所有年龄18岁的人员姓名列表
    print(mySql.searchNeedValue_byKeyName(keyName="姓名",value="123",needKeyName='字段标题1'))

    # 查询某个内容是否存在,返回bool
    print(mySql.checkExist(keyName="姓名",value="123"))

    # 修改 内容，只要符合的全部都会修改，只有修改唯一值，才能保证只改一行，否则所有符合条件的行都会被修改
    mySql.updateValue(byKey="字段标题1",byKey_value="JDID2121",changeKey="字段标题2",changeKey_value="666")



# 运行警局，负责程序运行
import time
from wadeTools.wadeTools_log import my_logger
import traceback
from os import execl
from sys import exit,executable,argv
from time import sleep

# import winsound

#播放警报
# def playNoticeSong():
    # winsound.PlaySound("SystemExit", winsound.SND_ALIAS)
# 重启任务
def restartProgram():
    for i in range(10):
        sleep(1)
        # winsound.PlaySound("SystemExit", winsound.SND_ALIAS)
    print('程序重启...')
    # 获取当前解释器路径
    p = executable
    # 启动新程序(解释器路径, 当前程序)
    execl(p, p, *argv)
    # 关闭当前程序
    exit()
# 统计任务耗时
def cost_time(func):
    """ 统计函数耗时时间"""
    def fun(*args, **kwargs):
        t = time.perf_counter()
        result = func(*args, **kwargs)
        print(f'函数 {func.__name__} 运行耗时:{time.perf_counter() - t:.8f} s')
        return result
    return fun

# 安全模式（出错了任务接着干）
def safe_Mode(*saveResult):
    """自治系统模式，出错只记录，不停下来出错先重试几次，重试次数满了后报错，由excep内部解决，由logging记录出错问题,返回的是元组"""
    def my_decorator(func):
        def wrapper(*args, **kwargs):
          try:
            # 执行被装饰的函数
            result = func(*args, **kwargs)
          except Exception as e:
            # 记录异常问题

            print(e, traceback.format_exc())
            my_logger.debug(e)
            my_logger.debug(traceback.format_exc())
            my_logger.debug("__________________________________________________________________")
            # 系统出错后返回 预设结果，不影响流程
            return saveResult
          else:
            # 返回装饰后的函数结果
            return result

        return wrapper
    #返回装饰器
    return my_decorator

# 出错报错模式开启
def unsafe_Mode():
    """依赖系统模式，出错记录后，停下来抛出错误给主线，出错先重试几次，重试次数满了后抛出错误，由logging记录出错问题"""
    def my_decorator(func):
        def wrapper(*args, **kwargs):
          try:
            # 执行被装饰的函数
            result = func(*args, **kwargs)
          except Exception as e:
            # 记录异常问题
            my_logger.debug(e)
            my_logger.debug(traceback.format_exc())
            my_logger.debug("__________________________________________________________________")
            raise Exception
          else:
            # 返回装饰后的函数结果
            return result

        return wrapper
    #返回装饰器
    return my_decorator




if __name__ == '__main__':
    @safe_Mode([1],[2])
    def task1():
        print(1+"3") #故意报错
    try:  # 这个是主程序设计的方式
      for i in range(5):
          print(task1())
    except:
      print(888888)



# -*- coding: UTF-8 -*-
import http.client
import urllib.parse
import http.client
import urllib.parse
import urllib.request
import json
from aliyunsdkcore.client import AcsClient #阿里云核心代码库 安装方法：pip install aliyun-python-sdk-core-v3
from aliyunsdkcore.request import CommonRequest #阿里云官方核心代码库

"""
文字转语音的api，wordToVolic(text) 可以直接用
"""
def wordToVolice(text):
    """
    文字输出为音频
    :param text:需要转换的文字
    :return: 直接输出mp3
    """
    appKey = 'Afmo70O9f2sovWOH'
    uID = 'LTAI4GCaEY7V4Cigqxpgg1mV'
    uKEY = 'iR3WppxVLSd5BPx58WeAy5PA0r5g0h'
    text = f'{text}'
    voice = 'dahu'  # 发音人
    saveName = 'good.mp3'
    volume = 100
    makeMp3(appKey, uID, uKEY, text, voice, saveName, volume)



## 获取token值
def get_token(uID,uKEY):
    # 创建AcsClient实例
    client = AcsClient(
        uID,  # 为阿里云后台创建的 accesskey id
        uKEY,  # 为阿里云后天创建的  accesskey secret
        "cn-shanghai"
    )
    # 创建request，并设置参数
    request = CommonRequest()
    request.set_method('POST')
    request.set_domain('nls-meta.cn-shanghai.aliyuncs.com')
    request.set_version('2019-02-28')
    request.set_action_name('CreateToken')
    response = client.do_action_with_exception(request)
    token_result = eval(response.decode('utf-8'))
    token_result = token_result['Token']['Id']
    #print(token_result)
    return token_result

# @wadeTools_Request.retryRequest
def processGETRequest(appKey, token, text, audioSaveFile, format, sampleRate,voice,volume) :
    host = 'nls-gateway.cn-shanghai.aliyuncs.com'
    url = 'https://' + host + '/stream/v1/tts'
    # 设置URL请求参数
    url = url + '?appkey=' + appKey
    url = url + '&token=' + token
    url = url + '&text=' + text
    url = url + '&format=' + format
    url = url + '&sample_rate=' + str(sampleRate)
    url = url + '&voice=' + str(voice)
    url = url + '&voice=' + str(volume)
    # voice 发音人，可选，默认是xiaoyun。
    # url = url + '&voice=' + 'xiaoyun'
    # volume 音量，范围是0~100，可选，默认50。
    # url = url + '&volume=' + str(50)
    # speech_rate 语速，范围是-500~500，可选，默认是0。
    # url = url + '&speech_rate=' + str(0)
    # pitch_rate 语调，范围是-500~500，可选，默认是0。
    # url = url + '&pitch_rate=' + str(0)
    print(url)
    # Python 2.x请使用httplib。
    # conn = httplib.HTTPSConnection(host)
    # Python 3.x请使用http.client。
    conn = http.client.HTTPSConnection(host)
    conn.request(method='GET', url=url)
    # 处理服务端返回的响应。
    response = conn.getresponse()
    print('Response status and response reason:')
    print(response.status ,response.reason)
    contentType = response.getheader('Content-Type')
    print(contentType)
    body = response.read()
    if 'audio/mpeg' == contentType :
        with open(audioSaveFile, mode='wb') as f:
            f.write(body)
        print('The GET request succeed!')
    else :
        print('The GET request failed: ' + str(body),'等待2秒钟后重试')
        raise Exception  #呼叫装饰器，让他重连
    conn.close()
def processPOSTRequest(appKey, token, text, audioSaveFile, format, sampleRate) :
    host = 'nls-gateway.cn-shanghai.aliyuncs.com'
    url = 'https://' + host + '/stream/v1/tts'
    # 设置HTTPS Headers。
    httpHeaders = {
        'Content-Type': 'application/json'
        }
    # 设置HTTPS Body。
    body = {'appkey': appKey, 'token': token, 'text': text, 'format': format, 'sample_rate': sampleRate}
    body = json.dumps(body)
    print('The POST request body content: ' + body)
    # Python 2.x请使用httplib。
    # conn = httplib.HTTPSConnection(host)
    # Python 3.x请使用http.client。
    conn = http.client.HTTPSConnection(host)
    conn.request(method='POST', url=url, body=body, headers=httpHeaders)
    # 处理服务端返回的响应。
    response = conn.getresponse()
    print('Response status and response reason:')
    print(response.status ,response.reason)
    contentType = response.getheader('Content-Type')
    print(contentType)
    body = response.read()
    if 'audio/mpeg' == contentType :
        with open(audioSaveFile, mode='wb') as f:
            f.write(body)
        print('The POST request succeed!')
    else :
        print('The POST request failed: ' + str(body))
    conn.close()


def makeMp3(appKey,uID,uKEY,text,voice,saveName,volume):
    # appKey = 'Afmo70O9f2sovWOH'
    # uID = 'LTAI4GCaEY7V4Cigqxpgg1mV'
    # uKEY = 'iR3WppxVLSd5BPx58WeAy5PA0r5g0h'
    # text = '我爱你，爱你爱爱爱爱哎哎哎'
    # voice = 'dahu'  # 发音人

    token = get_token(uID, uKEY)
    # 采用RFC 3986规范进行urlencode编码。
    textUrlencode = text
    # Python 2.x请使用urllib.quote。
    # textUrlencode = urllib.quote(textUrlencode, '')
    # Python 3.x请使用urllib.parse.quote_plus。
    textUrlencode = urllib.parse.quote_plus(textUrlencode)
    textUrlencode = textUrlencode.replace("+", "%20")
    textUrlencode = textUrlencode.replace("*", "%2A")
    textUrlencode = textUrlencode.replace("%7E", "~")
    print('text: ' + textUrlencode)
    audioSaveFile = saveName   #good.mp3  文件名
    format = 'mp3'
    sampleRate = 16000
    # GET请求方式
    processGETRequest(appKey, token, textUrlencode, audioSaveFile, format, sampleRate, voice,volume)
if __name__ == '__main__':
    appKey = 'Afmo70O9f2sovWOH'
    uID = 'LTAI4GCaEY7V4Cigqxpgg1mV'
    uKEY = 'iR3WppxVLSd5BPx58WeAy5PA0r5g0h'
    text = 'etc全称Electronicetc全称ElectronicTollTollCollection，意思是全自动电子收费系统，是国际上正在努力开发并推广的一种用于公路、大桥和隧道的电子自动收费系统，是智能交通系统的服务功能之一Collection，意思是全自动电子收费系统，是国际上正在努力开发并推广的一种用于公路、大桥和隧道的电子自动收费系统，是智能交通系统的服务功能之一'
    voice = 'dahu'  # 发音人
    saveName = 'good.mp3'
    volume = 100
    makeMp3(appKey,uID,uKEY,text,voice,saveName,volume)




# -*- encoding=utf-8 -*-
"""
轮寻,txt 增加内容，读取内容
txt文件对象 = wadeTxtObject(filename='111.txt')
txt文件对象.deleteItem("")
"""
import random
import re
from wadeTools.wadeTools_log import my_logger
class wadeTxtObject:
    """
    txt扩展类支持读取 OBJ.data   增加：OBJ.addxxxx  删除OBJ。delxxxxx
    """
    def __init__(self, filename):
        self.filename = filename
        self.data = []
        self.__load()
    def getTextList(self):
        """获取文本的内容"""
        self.deleteBlankLines()
        return self.data

    def lunxunTxt(self):
        """
        随机返回文本的一行：返回值为str类型
        :param filepath: 传入文件相对路径或者绝对路径：./1.txt  c:/1.txt
        :return:列表
        """
        return str(random.choice(self.data))
    def additem_to_Txt(self, text):
        # 续写txt，不存在则自动创建
        if type(text) != str:  # 判断是否是是字符串，不是的话，强制改为字符串
            text = str(text)
        self.data.append(text)
        self.save()

    def addList_to_TXT(self, list):
        # 重新保存txt，不存在则自动创建
            for i in list:
                if type(i) != str:  # 判断是否是是字符串，不是的话，强制改为字符串
                    i = str(i)
                self.additem_to_Txt(i)
    def deleteItem(self, text):
        if text in self.data:
            self.data.remove(text)
            self.save()
        else:
            my_logger.warning("列表删除查无该数据")
    def deleteBlankLines(self):
        """
        删除所有的空行
        :return:None
        """
        self.data = list(filter(None, self.data))
        self.save()

    def findWord(self, Word):
        """
        列出txt中包含某个内容的列表
        :param findWord:  包含的内容
        :return: 返回列表
        """
        matchList = []
        for i in self.data:
            if Word in i:
                matchList.append(i)
        return matchList

    def getListByText_form_Sign(self, lineWord):
        """
        按照约定格式取内容，用于取得账号信息
        print(OBJ.getListByText_form_Sign("你好@----@你好发@----@发发@----@发的"))
        解释：'@----@' 是我们要分割的标记       lineWord 输入字符串 "你好@----@你好发@----@发发@----@发的"
        返回['你好', '你好发', '发发', '发的']
        """

        resultList = re.split('@----@', lineWord)
        # 输出结果
        try:  # 去除空字符
            resultList.remove("")
        except:
            pass
        return resultList

    def clear(self):
        self.data.clear()  # 清空self.data列表
        self.save()  # 保存清空后的内容到文件

    def __load(self):  # 内部函数
        try:
            with open(self.filename, 'r', encoding='utf-8') as file:
                self.data = [line.strip() for line in file]  # 读取每一行并删除前后的空白字符
        except FileNotFoundError:
            self.save()
            with open(self.filename, 'r', encoding='utf-8') as file:
                self.data = [line.strip() for line in file]  # 读取每一行并删除前后的空白字符

    def save(self):
        with open(self.filename, 'w', encoding='utf-8') as file:
            for line in self.data:
                file.write(line + '\n')  # 在每条文本后添加换行符
        self.__load()



if __name__ == '__main__':


    TXT111 = wadeTxtObject(filename='111.txt')

    print(TXT111.getListByText_form_Sign("你好@----@你好发@----@发发@----@发的.html"))






"""图片功能库cv2是传统的BGR模式，pil的image是rgb模式  CV2和PIL读取图像方法与区别对比https://www.cnblogs.com/qdulixing/p/16146861.html"""
import cv2
# 读取图片
import numpy as np

from wadeTools import wadeTools_log

my_logger = wadeTools_log.my_logger

import base64
import requests

def image_url_to_base64(image_url):
    response = requests.get(image_url)
    image_content = response.content
    return base64.b64encode(image_content).decode('utf-8')



def wadeImageRead(image_path):
    """
    利用cv2读取图片，通道默认为BGR,获取np矩阵
    :param image_path:图片的路径，绝对和相对的中英文都行
    :return: <class 'numpy.ndarray'>
    """
    img = cv2.imdecode(np.fromfile(f"{image_path}", dtype=np.uint8), -1)  # 这个可以接纳中文路径

    # img = cv2.imread("C:/Users/wade/Desktop/1.png",cv2.IMREAD_COLOR)  # 默认以BGR形式打开 ,不支持中文，不用了
    return img


# 多个图片拼接同时展示
def wadeImageShowList(imgs, size, layout,sideWidth=4):
    #创建高度的白边
    whiteside_h = np.ones((size[0], sideWidth, 3), dtype='uint8') * 100  #4是4个像素，3是三个维度
    # whiteside_h = np.array(np.random.choice(55,(size[0], sideWidth, 3)),dtype=np.uint8)  #4是4个像素，3是三个维度
    #创建宽度的白边,因为上边宽度增加了
    whiteside_w = np.ones((sideWidth, size[1]+sideWidth, 3), dtype='uint8') * 100  #4是4个像素，3是三个维度
    # whiteside_w = np.array(np.random.choice(55,(sideWidth, size[1]+sideWidth, 3)),dtype=np.uint8)  #4是4个像素，3是三个维度


    imgh =None
    null_img = None
    imgw = None
    """
    多个图片拼接展示,imgs为需要展示的图片数组
    size为展示时每张图片resize的大小
    layout为展示图片的布局例如（3，3）代表3行3列）
    :param imgs: np的图片数组
    :param size: 每张小图的分辨率 元组
    :param layout: 几行几列 （3,2） 3行2列
    :return: np的图片一张
    """
    w = layout[0]
    h = layout[1]
    x = imgs[0].shape[2]  #获取通道数
    if w * h - len(imgs) > 0:
        null_img = np.zeros((size[0]+sideWidth, size[1]+sideWidth, x), dtype='uint8')
        # 注意这里的dtype需要声明为'uint8'，否则和图片矩阵拼接时会导致图片的矩阵失真
        null_img = null_img * 255
    # null_img用来填充当图片数量不足时，布局上缺少的部分
    for i in range(len(imgs)):
        # 和同学交流的过程中发现如果出现有的图片通道不足的时候，会出现合并问题
        # 思考了一下，使用下面这段代码将灰度图片等通道数不足的图片补充成3个通道就ok
        if len(imgs[i].shape) < 3:
            imgs[i] = np.expand_dims(imgs[i], axis=2)
            imgs[i] = np.concatenate((imgs[i], imgs[i], imgs[i]), axis=-1)
        imgs[i] = cv2.resize(imgs[i], size)

        #图片右边和下边加间隔条
        aaa = np.hstack((imgs[i], whiteside_h))  # 水平方向堆叠
        imgs[i] = np.vstack((aaa, whiteside_w))  # 垂直方向堆叠
    for j in range(h):
        for k in range(w):
            if j * w + k > len(imgs) - 1:
                f = k
                while f < w:
                    if f == 0:
                        imgw = null_img
                    else:
                        imgw = np.hstack((imgw, null_img))
                    f = f + 1
                break
            if k == 0:
                imgw = imgs[j * w]
            else:
                imgw = np.hstack((imgw, imgs[j * w + k]))
            print(j * w + k)
        if j == 0:
            imgh = imgw
        else:
            imgh = np.vstack((imgh, imgw))
    return imgh


# 高宽功能：
def wadeImageGetWidth_height(numpy_image):
    """
    :param numpy_image:
    :return:图片宽高
    """
    height = numpy_image.shape[0]  # 高度（行数）
    width = numpy_image.shape[1]  # 宽度（列数）
    my_logger.debug(f"宽:{width}像素,高:{height}像素")
    return width, height


def wadeImageCut(numpy_image, x, y, width, height):
    """
    裁剪图片高度,按照矩形尺寸来切割
     x: 左上角距离左边距离    -(0,0)-(1,0)-(2,0)--------(x,0)-
     y: 左上角距离顶部距离    -(0,1)-(1,1)-(2,1)--------(x,1)
     width: 矩形的宽度       -(0,2)-(x,y)-(2,2)--------(x+width,2)
     height: 矩形的高度      -(0,3)-(x,y+height)-(2,3)--------(x+width,y+height)

    :param numpy_image: np类型的图片
    :param x: 起始点x坐标
    :param y: 起始点y坐标
    :param width: 需要切割矩阵的宽度
    :param height:需要切割矩阵的高度
    :return: np图片
    """
    endX = x + width
    endY = y + height  # 因为截取的坐标可能会超出图片，所以进行最大化修正
    img_w, img_h = wadeImageGetWidth_height(numpy_image)
    if x > img_w or y > img_h:
        my_logger.info("裁切的起始点出现问题，已经重置为x=0，y=0")
        x, y = 0, 0
    if x + width > img_w:
        my_logger.info("裁切的矩形超出图片宽度，x+width已调整为图片最大宽度")
        endX = img_w
    if y + height > img_h:
        my_logger.info("裁切的矩形超出图片宽度，y+height已调整为图片最大宽度")
        endY = img_h

    imgCut = numpy_image[y:endY, x:endX]
    return imgCut


# 通道功能：
def wadeImage_BGR_to_RGB(numpy_image_BGR):
    """
    BGR和RGB的通道转换
    :param numpy_image_BGR:cv2读取的BGR通道图片
    :return: 转换的RGB通道图片
    """
    my_logger.debug(f"BGR和RGB的通道转换")
    numpy_image_RGB = numpy_image_BGR[:, :, ::-1]
    return numpy_image_RGB


def wadeImageGet_B_G_R(numpy_image_BGR):
    my_logger.debug(f"分别获取图片的B、G、R通道")
    B = numpy_image_BGR[:, :, 0]
    G = numpy_image_BGR[:, :, 1]
    R = numpy_image_BGR[:, :, 2]
    return B, G, R


# 显示功能
def wadeImageShow(numpy_image, waitTime=0):
    """
    显示图片,等待时间默认为为永久,waitTime 1000是1秒
    :param numpy_image: cv2读取的图片（np）
    :return: NULL
    """
    cv2.imshow(f'123.jpg', numpy_image)
    cv2.waitKey(waitTime)


if __name__ == '__main__':





    """分割展示四幅图方法"""
    evaJPG = wadeImageRead('333.jpg')
    wadeImageGetWidth_height(evaJPG)
    img_w, img_h = wadeImageGetWidth_height(evaJPG)
    left_img = wadeImageCut(evaJPG, x=0, y=0, width=img_w // 2, height=img_h // 2)
    right_img = wadeImageCut(evaJPG, x=img_w // 2, y=0, width=img_w // 2, height=img_h // 2)
    down_right = wadeImageCut(evaJPG, x=0, y=img_h // 2, width=img_w // 2, height=img_h // 2)
    down_lefg = wadeImageCut(evaJPG, x=img_w // 2, y=img_h // 2, width=img_w // 2, height=img_h // 2)
    resultImg1 = wadeImageShowList([left_img, right_img, down_right,down_lefg ], (600,600), (2,2),sideWidth=0)
    resultImg2 = wadeImageShowList([left_img, right_img, down_right,down_lefg ], (600, 600), (2,2),sideWidth=200)
    resultImg3 = wadeImageShowList([left_img, right_img, down_right,down_lefg ], (600, 600), (2,2),sideWidth=100)
    resultImg4 = wadeImageShowList([left_img, right_img, down_right,down_lefg ], (600, 600), (2,2),sideWidth=10)
    resultImg5 = wadeImageShowList([left_img, right_img, down_right,down_lefg ], (600, 600), (2,2),sideWidth=20)
    cv2.imwrite('1.png',resultImg1)
    cv2.imwrite('2.png',resultImg2)
    cv2.imwrite('3.png',resultImg3)
    cv2.imwrite('4.png',resultImg4)
    cv2.imwrite('5.png',wadeImage_BGR_to_RGB(resultImg4))

    # finallyImg = wadeImageShowList([resultImg1,resultImg2,resultImg3,resultImg4],(600, 600), (1,4))
    # wadeImageShow(cv2.flip(finallyImg,1))

#
# #保存图片
# cv2.imwrite('123.png',img)
#
# #打印图片大小
# print(img.shape)
#
# #获取高宽
# height = img.shape[0]
# width = img.shape[1]
#
# #裁剪 ,顺序是
# """  a: 左上角距离顶部
#      b: 左下角距离顶部
#      c: 左上角距离左边距离
#      d: 右上角距离左边距离"""
# cut_img = img[0: height, 119: width-119]
# cv2.imwrite('1231.png',cut_img)
#
# ##cv2转base64
# import cv2
#
#
# def cv2_base64(image):
#     base64_str = cv2.imencode('.jpg', image)[1].tostring()
#     base64_str = base64.b64encode(base64_str)
#     return base64_str
#
#
# ##base64转cv2
# import base64
# import numpy as np
# import cv2
#
#
# def base64_cv2(base64_str):
#     imgString = base64.b64decode(base64_str)
#     nparr = np.fromstring(imgString, np.uint8)
#     image = cv2.imdecode(nparr, cv2.IMREAD_COLOR)
#     return image



#coding:utf-8
import copy
import hashlib
import json
import operator
import random

import requests
from wadeTools import wadeTools_Request,wadeTools_UserJSON
'''大淘客加密请求详情'''
def get_dtk_detail(skuIds,appKey,appSecret,version):  #通过商品id获取商品信息
    url = 'https://openapi.dataoke.com/api/dels/jd/goods/get-details'
    def md5_sign(args=None):
        def md5(arg):
            md5 = hashlib.md5()
            loc_bytes_utf8 = arg.encode(encoding="utf-8")
            md5.update(loc_bytes_utf8)
            return md5.hexdigest()

        copy_args = args
        # 对传入的参数 按照key 排序
        sorted_args = sorted(copy_args.items(), key=operator.itemgetter(0))
        tmp = []
        for i in sorted_args:
            tmp.append('{}={}'.format(list(i)[0], list(i)[1]))
        sign = md5('&'.join(tmp) + '&' + 'key={}'.format(appSecret)).upper()
        copy_args['sign'] = sign
        return copy_args
    sign = md5_sign({'appKey': appKey, 'version': version, 'skuIds': skuIds})
    wadeTools_Request.wade_Request_get_byParams(url,addHeader={},params=sign)
    html = requests.get(url, params=sign)

    return html

def getMyLink(materialId,appKey,appSecret,version,unionId,limitLength):
    # 京东转链
    url = 'https://openapi.dataoke.com/api/dels/jd/kit/promotion-union-convert'
    def md5_sign(args=None):
        def md5(arg):
            md5 = hashlib.md5()
            loc_bytes_utf8 = arg.encode(encoding="utf-8")
            md5.update(loc_bytes_utf8)
            return md5.hexdigest()

        copy_args = args
        # 对传入的参数 按照key 排序
        sorted_args = sorted(copy_args.items(), key=operator.itemgetter(0))
        tmp = []
        for i in sorted_args:
            tmp.append('{}={}'.format(list(i)[0], list(i)[1]))
        sign = md5('&'.join(tmp) + '&' + 'key={}'.format(appSecret)).upper()
        copy_args['sign'] = sign
        return copy_args
    sign = md5_sign({'materialId': materialId,'appKey': appKey, 'version': version, 'unionId': unionId,'chainType': 3})
    response = wadeTools_Request.wade_Request_get_byParams(url,addHeader={},params=sign)
    print(response.json())
    longURL = response.json()['data']['longUrl']
    if len(longURL)>=200:
        return response.json()['data']['shortUrl']
    else:
        return longURL


# 百度下拉长尾词
def baiduXiaLaWords(word):
    try:
        response = requests.get(url=f'http://suggestion.baidu.com/su?wd=word')
        baiduWordsList = json.loads(response.text.lstrip('window.baidu.sug(').rstrip(""");""").lstrip('{q:"冰箱",p:false,').rstrip('}'))
        random.shuffle(baiduWordsList)
        return baiduWordsList
    except:
        return []
if __name__ == '__main__':

    baiduXiaLaWords('长尾词')
    baiduLongWords =baiduXiaLaWords(word="fdsaf").__iter__()
    exit()
    appKey = '624d402f66ea7'
    appSecret = '91e0ac86eaf158f2027c740927f27fdb'
    version = 'v1.0.1'  # 当前版本号
    skuIds = 10037813209308  #京东的商品内容
    materialId = f'https://item.jd.com/{skuIds}.html'
    unionId = "1001706833" #推广者
    # limitLength = 200 # 推广链接的长度
    item_detailJson = get_dtk_detail(skuIds,appKey,appSecret,version).json()
    # print(item_detailJson)  # 打印商品详情
    from wadeTools import wadeTools_UserJSON
    actualPrice= wadeTools_UserJSON.get_dict_by_key(will_find_dist=item_detailJson,find_keys='actualPrice')
    detailImages= wadeTools_UserJSON.get_dict_by_key(will_find_dist=item_detailJson,find_keys='detailImages')[0]
    print(actualPrice,detailImages)
    # exit()
    print(getMyLink(materialId,appKey,appSecret,version,unionId,200))
    # jd_skuName = wadeTools_UserJSON.get_dict_by_key(get_dtk_detail(skuIds,appKey,appSecret,version).json(), find_keys='skuName')  # 商品名
    # jd_originPrice = wadeTools_UserJSON.get_dict_by_key(get_dtk_detail(skuIds,appKey,appSecret,version).json(), find_keys='originPrice')  # 原价
    # jd_commission = wadeTools_UserJSON.get_dict_by_key(get_dtk_detail(skuIds,appKey,appSecret,version).json(), find_keys='commission')  # 佣金
    # print(jd_skuName,jd_originPrice,jd_commission)





from setuptools import find_packages,setup
setup(
 name='wadeTools',
 version='1.0.1',
 packages = find_packages(),
 url ='http://www.tbzhu.com',
 author = 'wade',
 author_email = '317909531@qq.com',
 )


#!/usr/bin/env python
# coding=utf-8
"""
使用方法：

Ini_Data = ReadConfig('config.ini')
"""
import configparser
import os
from wadeTools import wadeTools_log
from wadeTools.wadeTools_Print import wadePrint
my_logger = wadeTools_log.my_logger
class ReadConfig:
    """定义一个读取配置文件的类"""

    def __init__(self, filepath="filepath"):
        root_dir = os.path.dirname(os.path.abspath('.'))
        # self.configpath = os.path.join(root_dir, f"{filepath}")
        self.configpath = os.path.join(os.getcwd(), filepath)

        self.cf = configparser.RawConfigParser()
        try:self.cf.read(self.configpath,encoding='utf-8')
        except UnicodeDecodeError as e:
            my_logger.error(f"XXXXXXX:程序已停止，请将读取的文本编码转为UTF-8。错误编码的文件是:{os.path.join(os.getcwd(),filepath)}，\n   {e}")
            exit()
    # self.cf.read(configpath,encoding='utf-8')
    def getFilepath(self):
        return self.configpath
    def get_param(self, title,param):
        try:
            value = self.cf.get(title, param)
            return value
        except Exception as e:
            wadePrint(e)
            return ""


    def setItem(self, title, key, val):  #修改内容
        """
        :param title: USER  ini显示是[USER]
        :param key:   key    ：abc = 666
        :param val:   value  666   ：abc = 666
        :return:
        """
        try:
            self.cf[title]
        except:
            self.cf.add_section(title)

        if title == '' or key == '':
            return False
        self.cf[title][key] = val
        return True

    def saveIni(self,real_path='config.ini'):  #保存修改
        """

        :param real_path: xxx.ini
        :return:
        """
        # root_dir = os.path.dirname(os.path.abspath('.'))
        # self.configpath = os.path.join(root_dir, real_path)
        self.configpath = os.path.join(os.getcwd(), real_path)

        for title in self.cf:
            for key in self.cf[title]:
                self.cf.set(title, key, self.cf[title][key])
        self.cf.write(open(self.configpath,"w",encoding='utf-8'))

if __name__ == '__main__':

    #绝对路径
    Ini_Data = ReadConfig('config.ini')
    runNumNow = Ini_Data.get_param('USER', "【中】")
    Ini_Data.setItem('USER',"【中】",[123,34])  #修改
    Ini_Data.saveIni('config.ini')  #保存
    wadePrint(runNumNow)




"""
日志模块，我在2022年8月思考我只有两种需求，做软件时，将print用my_logger.debug()代替
例：
from wadeTools import wadeTools_log
my_logger = wadeTools_log.my_logger

    my_logger = MyLogger.create_logger   #初始化,由于是单例模式，整个默认不用初始化了
    my_logger.debug(输出详细信息)         #打印
    my_logger.info("输出关键信息信息）     #打印
    mylogger.setlevel("DEBUG")   #调试模式
    mylogger.setlevel("INFO")    #运行模式

"""

import logging
import threading
from logging.handlers import TimedRotatingFileHandler
import time

'''

默认日志等级划分

DEBUG    等级最低的，最详细的日志信息，典型应用场景是 问题诊断
INFO     信息详细程度仅次于DEBUG，通常只记录关键节点信息，用于确认一切都是按照我们预期的那样进行工作
WARNING  当某些不期望的事情发生时记录的信息（如，磁盘可用空间较低），但是此时应用程序还是正常运行的
ERROR    由于一个更严重的问题导致某些功能不能正常运行时记录的信息
CRITICAL 当发生严重错误，导致应用程序不能继续运行时记录的信息

'''



class MyLogger():
    """才用了单例模式，保证日志记录器整个项目中只能有一个"""
    instance = None
    __init__flag = False
    lock = threading.RLock()
    def __init__(self):
        if not MyLogger.__init__flag:  #如果没有实例化过，就运行一次，如果实例化过了，这里的代码就不会运行了
            # print('init执行了')
            MyLogger.__init__flag = True
            self.my_logger = MyLogger.create_logger()
    def __new__(cls, *args, **kwargs):
        # 返回空对象，init中的跨文件不能用
        # 返回空对象
        with cls.lock:
            if cls.instance is None:
                cls.instance = super().__new__(cls)
            return cls.instance
    @staticmethod  # 静态方法,使用时可用类/实例调用,只在名义上归类管理
    def create_logger():

        # 获取日志收集器,并设置名称为my_logger(若不设置名字,则为默认日志收集器root)
        my_logger = logging.getLogger("my_logger")
        my_logger.setLevel("DEBUG")  # 收集等级默认为DEBUG

        # 创建一个输出到控制台的处理器
        control_hander = logging.StreamHandler()
        control_hander.setLevel("WARNING")  # 设置输出到控制台的处理器的输出等级为ERROR
        my_logger.addHandler(control_hander)  # 添加处理器并绑定在日志收集器上   ,addHandler:增加处理器, removeHandler:删除处理器

        # 用文件记录日志，记录级别为DEBUG
        filename = time.strftime("%Y%m%d") + ".txt"
        import os
        path = os.getcwd()
        path = path + "/运行日志"
        if not os.path.exists(path):
            os.makedirs(path)

        if not os.path.exists(filename):
            with open(os.path.join(os.getcwd(), path, filename), 'a+', encoding='utf-8') as f:
                # f.write("日志记录")
                pass # 新建文件
        file_handler = TimedRotatingFileHandler(filename=os.path.join(os.getcwd(), path, filename), when='D',
                                                interval=1, encoding='utf-8')
        file_handler.setLevel("DEBUG")  # 设置输出到文件的处理器的输出等级为DEBUG
        my_logger.addHandler(file_handler)

        # 设置输出到文件与控制台的格式
        formatter = logging.Formatter('%(filename)s-->line:%(lineno)d    %(levelname)s   %(asctime)s\n%(message)s\n')
        file_handler.setFormatter(formatter)
        control_hander.setFormatter(formatter)
        return my_logger
my_logger = MyLogger().my_logger # 默认初始化可直接采用类调用
# a = 100
#
# # # assert a==0
# # my= MyLogger() #可创建实例调用

# my_logger.debug(my_logger)
# my_logger.debug("in3fo")
# my_logger.info("info")
# my_logger.setLevel('INFO')
# my_logger.debug(a)
# my_logger.debug("in3fo")
# my_logger.info("info")
# # my_logger.warning("warn")
# # my_logger.error("error")
# # my_logger.critical("critical")



#!/usr/bin/env python
#coding=utf-8
# author:wade
# contact: 317909531@qq.com
# datetime:2022/4/5 22:14
import re
"""
文件说明：

---------------------------文件读写----------------------------
文件的读写：保存文件，读取文件列表
wadeRead  # ('web.data','rb')   读,返回字典列表
    dir: 相对路径和文件名 例'web.data'
    writeType: 例'rb' 等写入类型 string
wadeSave  # ('wade.data','wb',[])   保存列表不如保存成dict，可以保存很多内容
    dir: 相对路径和文件名 例'web.data'
    readType: 例'wb' 等写入类型 string
    dataList: 存储的内容 list

---------------------------保存日志----------------------------
#读取日志,返回列表类型  写死日志文件：'运行日志.log'
readLog()    #读取日志，文件不存在自动创建
saveLog(msg) #（'我是日志内容'）  保存日志到文件,自动创建

---------------------------下载文件----------------------------
文件和文件夹的操作函数（读写/下载）
wadeDownloadFile ：下载网络图片/视频,不显示进度，自己写请求，
    filePath: 'movie'
    fileName: 1.jpg 1.mp3 .1.exe
    html: html = request.get(xxx)
wadeDownLoadStreamFile :下载网络图片/视频，FilePath文件路径  1.jpg  movie/1.jpg  c:/1.jpg  1.mp4
    filePath: 'movie'
    fileName: 1.jpg 1.mp3 .1.exe
    html: html = request.get(xxx)
wadeDownLoadStreamFileByUrl ：直接填写url，显示进度，请求函数里已实现
    filePath: 'movie'
    fileName: 1.jpg 1.mp3 .1.exe
    url: 'www.baidu.com/1.exe'


wadeDownLoadStreamFileByUrl_AddHeader： 可以动态添加header的临时属性
    filePath: 'movie'
    fileName: 1.jpg 1.mp3 .1.exe
    url: 'www.baidu.com/1.exe'

----快捷代码------
append 续写  read 是读  write是写
import wadeTools_ReadAndWrite
wadePrint(wadeTools_ReadAndWrite.wadeRead('wade.data', 'rb'))
wadeTools_ReadAndWrite.wadeSave('wade.data','wb',[1,2])

"""
import os
import pickle
import random
import time
import re
import traceback
import requests
from wadeTools import wadeTools_log
from wadeTools.wadeTools_Print import wadePrint,wadeRedPrint
my_logger = wadeTools_log.my_logger

import json
class wadeSetObject:
    """
    集合扩展类，支持读取 load， 单条增add ， 列表增updata，删remove查query
    """
    def __init__(self, filename):
        self.filename = filename
        self.data = set()
        self.load()

    def add(self, item):
        self.data.add(item)
        self.save()
    def updateList(self, item:list):
        self.data.update(item)
        self.save()

    def remove(self, item):
        if item in self.data:
            self.data.remove(item)
            self.save()
        else:
            wadePrint(f"删除的 {item} 在文件列表中不存在，忽略")

    def query(self, item):
        return item in self.data

    def load(self):
        try:
            with open(self.filename, 'r', encoding='utf-8') as file:
                self.data = set(json.load(file))
        except FileNotFoundError:
            self.save()
            with open(self.filename, 'r', encoding='utf-8') as file:
                self.data = set(json.load(file))
    def save(self):
        with open(self.filename, 'w',encoding='utf8') as file:
            json.dump(list(self.data), file)
class wadeTextObject:
    """
    txt扩展类支持读取 load， 单条增add ， 列表增updata，删remove查query
    """
    def __init__(self, filename):
        self.filename = filename
        self.data = []
        self.load()

    def load(self):
        try:
            with open(self.filename, 'r', encoding='utf-8') as file:
                self.data = [line.strip() for line in file]  # 读取每一行并删除前后的空白字符
        except FileNotFoundError:
            self.save()
            with open(self.filename, 'r', encoding='utf-8') as file:
                self.data = [line.strip() for line in file]  # 读取每一行并删除前后的空白字符

    def save(self):
        with open(self.filename, 'w', encoding='utf-8') as file:
            for line in self.data:
                file.write(line + '\n')  # 在每条文本后添加换行符

    def add(self, text):
        self.data.append(text)
        self.save()

    def remove(self, text):
        if text in self.data:
            self.data.remove(text)
            self.save()

    def search(self, text):
        return text in self.data
    def getListByText_form_Sign(self,text):
        """
        getListByText_form_Sign load，约定分隔符为这个符号@---@
        把txt通过约定的标记拆分为列表返回
        """


        # 输入字符串
        # input_str = "你好@----@你好发@----@发发@----@发的"
        # 使用正则表达式来分割字符串
        # '@----@' 是我们要分割的标记
        # 使用 re.split() 函数来根据这个标记分割字符串
        resultList = re.split('@----@', text)
        # 输出结果
        try:  # 去除空字符
            resultList.remove("")
        except:
            pass
        return resultList
    def clear(self):
        self.data.clear()  # 清空self.data列表
        self.save()  # 保存清空后的内容到文件


def delSpecialName(STR):  #过滤掉windows文件不支持的字符串
    """
    过滤掉windows文件不支持的字符串
    :param STR: 待过滤的文本
    :return:
    """
    for i,j in ("/／","\\＼","?？","|︱","\"＂","*＊","<＜",">＞"):
        STR=STR.replace(i,j)
    return STR


def lunxunTxt(filepath):
    """
    随机返回文本的一行：返回值为str类型
    :param filepath: 传入文件相对路径或者绝对路径：./1.txt  c:/1.txt
    :return:列表
    """
    needList = readText(filepath)
    if needList==[]:
        return ""
    return str(random.choice(readText(filepath)))

def readText(filepath):
    """
    读取文本：每行读取为列表
    :param filepath: 传入文件相对路径或者绝对路径：./1.txt  c:/1.txt
    :return:列表
    """
    textlist = []
    try:

        for line in open(f'{filepath}',encoding='utf-8'):
            # 清洗空格后如果不为空就下一步处理
            if line.strip() != '':
                # my_logger.debug(f"本行内容为{line}")
                # 每行的数据都需要清洗空格后进行下一步处理
                abc = line.strip()
                textlist.append(abc)
            else:
                my_logger.debug("删除空行")
    except FileNotFoundError as e:
        # 找不到文件则新建,路径必须保证没错，否则也报错
        with open(f'{filepath}', 'w+', encoding='utf-8') as f:
            my_logger.debug(e,f"{filepath}不存在，自动新建")
    except UnicodeDecodeError as e:
        my_logger.error(f"！！！:程序已停止，请将读取的文本编码转为UTF-8，如果是GBK也会出错,错误编码文件:{filepath}，\n   {e}")
        exit()
    return textlist


def writeList_to_TXT(filename,list):
    # 重新保存txt，不存在则自动创建
    with open(f'{filename}','w+',encoding='utf8') as f:
        for i in list:
            f.write(f"{i.strip()}"+'\r')



def additem_to_Txt(filename,itemStr):
    # 续写txt，不存在则自动创建
    with open(f'{filename}','a+',encoding='utf8') as f:
        f.write(f"{itemStr.strip()}"+'\r')


def getInputBianliangName(BianLiang):
    # 获取变量的名字 的字符串
    stack = traceback.extract_stack()
    filename, lineno, function_name, code = stack[-2]
    vars_name = re.compile(r'\((.*?)\).*$').search(code).groups()[0]
    name = vars_name.replace('self.', '')
    wadePrint(name)
    return name

#保存列表不如保存成dict，可以保存很多内容
def wadeSave(dir,readType,dataDict:dict):  #返回的是字典
    """
    ('wade.data','wb',[])

    :param dir: 相对路径和文件名 例'web.data'
    :param readType: 例'wb' 等写入类型 string
    :param dataDict: 存储的内容 list
    :return:None
    """
    with open(dir,readType) as f:
        pickle.dump(dataDict, f)


#向已经生成的字典中添加项目
def wadeSave_AddItem(dir,readType,dataDict:dict):  #返回的是字典
    """
    写操作用：wb
    :param dir: 文件
    :param readType: wb 写入
    :param dataDict: 存的数据
    :return: None
    """
    if os.path.exists(dir):#存在该文件
        itemDict = wadeRead(dir,'rb')
        itemDict.update(dataDict)
        # ('wade.data','wb',[])
        # dir: 相对路径和文件名 例'web.data'
        # readType: 例'wb' 等写入类型 string
        # dataList: 存储的内容 list
        with open(dir,readType) as f:
            pickle.dump(itemDict, f)
    else:#不存在该文件
        my_logger.debug("创建新文件，条目加入成功")
        # wadePrint(dataDict)
        wadeSave(dir,"wb",dataDict)
#读,返回字典列表
import os
import pickle

def wadeRead(dir, writeType, Encoding='utf-8'):
    """
    读操作~用：rb
    :param dir: 文件路径和名称
    :param writeType: 读写模式（如 'rb', 'wb', 'r', 'w' 等）
    :param Encoding: 文件的编码，默认为 utf-8（只在文本模式下有效）
    :return: 读取到的内容，可能是字典或空字典
    """
    try:
        if os.path.exists(dir):  # 如果文件存在
            if 'b' in writeType:  # 如果是二进制模式
                with open(dir, writeType) as f:
                    dataDict = pickle.load(f)
            else:  # 如果是文本模式
                with open(dir, writeType, encoding=Encoding) as f:
                    dataDict = f.read()
            return dataDict
        else:  # 如果文件不存在
            wadeSave(dir, "wb", {})  # 使用二进制写入创建新文件
            my_logger.debug(f"创建新文件 {dir}")
            return {}
    except Exception as e:
        wadePrint(e)
        return {}

def wadeReadHtml(dir, writeType, Encoding='utf-8'):
        """
        读取HTML文件内容，并返回文件内容作为字符串
        :param dir: 文件路径和名称
        :param writeType: 读写模式（如 'r' 或 'rb' 等）
        :param Encoding: 文件的编码，默认为 utf-8（只在文本模式下有效）
        :return: HTML 文件内容或空字符串
        """
        try:
            if os.path.exists(dir):  # 如果文件存在
                if 'b' in writeType:  # 二进制模式，读取字节数据
                    with open(dir, writeType) as f:
                        content = f.read()
                else:  # 文本模式，读取文本数据
                    with open(dir, writeType, encoding=Encoding) as f:
                        content = f.read()
                return content  # 返回 HTML 文件的文本内容
            else:  # 如果文件不存在
                my_logger.debug(f"文件 {dir} 不存在")
                return ''
        except Exception as e:
            wadePrint(f"读取文件 {dir} 时发生错误：{e}")
            return ''

def get_current_time():
    from datetime import datetime
    current_time =time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(time.time()))
    # current_time = datetime.now().strftime("%Y-%m-%d, %H:%M:%S")
    return current_time

# 保存日志
def saveLog(msg):
    log_file_write = open("运行日志.log", mode='a', encoding='utf-8')
    log_file_write.writelines(f'{get_current_time()}:{msg}')

#读取日志,返回列表类型
def readLog():
    try:
        return open('运行日志.log', mode='r', encoding='utf-8').read().splitlines()
    except IOError as e:
        saveLog('日志文件Start')
        return []
def wadeDownLoadImage(filePath,fileName,url):
    # 下载图片
    # url = "https://example.com/image.jpg"
    response = requests.get(url, stream=True)

    if response.status_code == 200:
        with open(os.path.join(filePath,fileName), "wb") as f:
            for chunk in response.iter_content(chunk_size=1024):
                f.write(chunk)

def wadeDownloadFile(filePath,fileName,html):
    '''FilePath文件路径  FileName:文件名  html: html = request.get(xxx) ,请求自己写'''
    if not os.path.exists(filePath):
        os.makedirs(filePath)
    with open(os.path.join(filePath,fileName),'wb') as f:
        f.write(html.content)
        f.close()
def wadeDownLoadStreamFile(filePath,fileName,html):  #显示进度，html 是requests请求返回对象
    if not os.path.exists(filePath):
        os.makedirs(filePath)
    length = float(html.headers['content-length'])
    count = 0
    count_tmp = 0
    time1 = time.time()
    with open(os.path.join(filePath,fileName),'wb') as f:
        for streamData in html.iter_content(chunk_size=1024*8):
            if streamData:
                f.write(streamData)
                count += len(streamData)
                if time.time() - time1 > 0.5:
                    p = count / length * 100
                    speed = (count - count_tmp) / 1024 / 1024 / 2
                    count_tmp = count
                    wadePrint(f"\r下载状态{fileName} 进度:{'{:.2f}'.format(p)}%  Speed: {'{:.2f}'.format(speed)}M/S",end='')
                    time1 = time.time()
        f.close()
def wadeDownLoadStreamFileByUrl_AddHeader(filePath,fileName,url,addHeader=dict):  #显示进度，直接写了下载地址,附加了头文件，可以动态加入cookie
    if not os.path.exists(filePath):
        os.makedirs(filePath)
    from urllib.parse import urlparse  # 正则url标准库

    HEADERS = [
        'Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/77.0.3865.75 Safari/537.36',
        'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/79.0.3945.117 Safari/537.36',
        'Mozilla/5.0 (Windows;U;WindowsNT6.1;en-us)AppleWebKit/534.50(KHTML,likeGecko)Version/5.1Safari/534.50',
        'Mozilla/5.0 (Macintosh;IntelMacOSX10.6;rv:2.0.1)Gecko/20100101Firefox/4.0.1',
        'Mozilla/5.0 (Windows NT6.1;rv:2.0.1)Gecko/20100101Firefox/4.0.1',
        'Mozilla/5.0 (Macintosh;IntelMacOSX10_7_0)AppleWebKit/535.11(KHTML,likeGecko)Chrome/17.0.963.56Safari/535.11',
        'Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/77.0.3865.90 Safari/537.36',
        'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/63.0.3239.132 Safari/537.36',
        'Mozilla/5.0 (Windows NT 6.3; WOW64; rv:41.0) Gecko/20100101 Firefox/41.0',
        'Mozilla/5.0 (Windows NT 6.3; Trident/7.0; rv:11.0) like Gecko',
        'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/79.0.3945.88 Safari/537.36',
        'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/70.0.3538.102 Safari/537.36 Edge/18.18362',
        'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/69.0.3497.100 Safari/537.36',
        'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:71.0) Gecko/20100101 Firefox/71.0',
        'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/55.0.2883.87 UBrowser/6.2.4098.3 Safari/537.36',
        'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/63.0.3239.132 Safari/537.36',
        'Mozilla/5.0 (Macintosh;U;IntelMacOSX10_6_8;en-us)AppleWebKit/534.50(KHTML,likeGecko)Version/5.1Safari/534.50',
        'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/46.0.2486.0 Safari/537.36 Edge/13.10586',
        'Mozilla/5.0 (Windows; U; Windows NT 6.1; en-US) AppleWebKit/533.20.25 (KHTML, like Gecko) Version/5.0.4 Safari/533.20.27',
        'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_11) AppleWebKit/601.1.27 (KHTML, like Gecko) Chrome/47.0.2526.106 Safari/601.1.27',
        'Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.108 Safari/537.36',
        'Mozilla/5.0 (Windows NT 6.1; Win64; x64; rv:70.0) Gecko/20100101 Firefox/70.0',
        'Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/79.0.3945.79 Safari/537.36',
    ]
    headers = {
        'Accept': '*/*',
        # 'Accept-Language': 'zh-CN,zh;q=0.9,en;q=0.8',
        'User-Agent': random.choice(HEADERS),
        'Connection': 'keep-alive',
        'Host': f"{urlparse(url).netloc}",
        'Content-Type': 'application/json',
        # 'Cookie': cookie
    }
    if addHeader:
        headers.update(addHeader)
    wadePrint(headers)
    html = requests.get(url, headers=headers,stream=True)
    length = float(html.headers['content-length'])
    count = 0
    count_tmp = 0
    time1 = time.time()
    with open(os.path.join(filePath,fileName),'wb') as f:
        for streamData in html.iter_content(chunk_size=1024*8):
            if streamData:
                f.write(streamData)
                count += len(streamData)
                if time.time() - time1 > 0.5:
                    p = count / length * 100
                    speed = (count - count_tmp) / 1024 / 1024 / 2
                    count_tmp = count
                    wadePrint(f"\r下载状态{fileName} 进度:{'{:.2f}'.format(p)}%  Speed: {'{:.2f}'.format(speed)}M/S",end='')
                    time1 = time.time()
        f.close()
def wadeDownLoadStreamFileByUrl(filePath,fileName,url):  #显示进度，直接写了下载地址

    if not os.path.exists(filePath):
        os.makedirs(filePath)
    html = requests.get(url,stream=True)
    length = float(html.headers['content-length'])
    count = 0
    count_tmp = 0
    time1 = time.time()
    with open(os.path.join(filePath,fileName),'wb') as f:
        for streamData in html.iter_content(chunk_size=1024*8):
            if streamData:
                f.write(streamData)
                count += len(streamData)
                if time.time() - time1 > 0.5:
                    p = count / length * 100
                    speed = (count - count_tmp) / 1024 / 1024 / 2
                    count_tmp = count

                    time1 = time.time()
                    try:
                        from wadeTools import wadeTools_gol
                        gol=wadeTools_gol.Singletion()

                        gol.windows['jindu'].update(f"\r下载状态{fileName} 进度:{'{:.2f}'.format(p)}%  Speed: {'{:.2f}'.format(speed)}M/S")
                    except Exception as e:
                        # wadePrint(e)
                        wadePrint(f"\r下载状态{fileName} 进度:{'{:.2f}'.format(p)}%  Speed: {'{:.2f}'.format(speed)}M/S", end='')
                        pass
        f.close()

if __name__ == '__main__':

    #读写
    # additem_to_Txt('111.txt',[3,4])

    # wadePrint(lunxunTxt('111.txt'))
    # wadePrint(wadeRead('wade.data', 'rb'))
    # wadeSave_AddItem('wade.data',"wb",{"123":123})
    # wadeSave_AddItem('wade.data','wb',{'123':23})
    # abc =123
    # getInputBianliangName(abc)
    #
    # #日志
    # saveLog('123')
    #
    # #下载
    # wadeDownLoadStreamFileByUrl('1', '360.exe', 'http://down.360safe.com/setup.exe')
    # wadeDownLoadImage('.','222222.jpg','https://img-home.csdnimg.cn/images/20230921025407.png')
    title='4171539-九牧大力神家用马桶（11173-2-1/31KB-3）最新评测，销量说明一切-九牧（JOMOO）11173-2-1/31KB-3大力神.h'
    itle_for_filename = title.replace('/', '、')  # 将 / 替换为 _
    print(itle_for_filename)
    title='./未发布内容/4171539-九牧大力神家用马桶（11173-2-1、31KB-3）最新评测，销量说明一切-九牧（JOMOO）11173-2-1/31KB-3大力神.html'
    writeList_to_TXT(title,'fdfdf')
    pass









import json
from openai import OpenAI

client = OpenAI(
    api_key="sk-6fde63b6e8474910bf94c5dc32d9ed55",
    base_url="https://api.deepseek.com",
)

completion = client.chat.completions.create(
    # model="deepseek-chat",
    model="deepseek-reasoner",
    messages=[
        {
                "role": "system",
                "content": """用户给你一个商品的链接，要用搜索的方式，整合内容搜索百度，写一篇商品评测文章，我要把你的内容作为api数据，请不要加入额外的语言，这个链接是测评的对象，你要分析京东商品内容，查找竞品商品进行对比
格式要求：
第一，title：写一个标题，10到20子字的标题
第二，content：文章写2000字，内容结合搜索的内容，纵横对比，段落间留 @照片@ 的标记三个，方便我替换换成图片
第三，文章视角是使用用户的真实反馈，有配置表格，有专业优劣点评，不要看着像广告，并提取其中的关键信息，
写作要求：
1. **塑造写作个性**：“试着用那种轻松自然的语气来写，想象自己是个28岁的新媒体达人，时不时地用‘哈哈’、‘emmm’、‘说实话’这样的口语化词汇。最关键的是，要像在和朋友聊天一样自然。”
2. **调整语言风格**：“写作的时候记得：1.多用短句；2.避免太正式的词汇；3.可以用反问、感叹等口语化表达；4.适当加点幽默；5.用具体的例子来代替抽象的概念。”
3. **结尾互动**：“结尾的时候要有互动感，比如问‘你们有没有遇到类似的问题？’、‘欢迎在评论区分享你的经历’，让读者感到参与其中。”
以 JSON 的形式输出，输出的 JSON 需遵守以下的格式：\n\n{\n  \"title\": <10到20子字的标题>,\n  \"itemID\": <商品的链接>,\n  \"content\": <文章内容>\n}"""
        },
        {
                "role": "user",
                "content": "https://item.jd.com/100103222748.html"
        }
    ]
)

print(completion.choices[0].message.content)